%============================================================================================%
%   Plant allometry: Biomass in every organe [kg] estimated from stem density (Timber), Leaf
%   Mass per Area (LMA) and the size of the individual (h): height of seedlings (hsg), height at maturity (hmat), maximal height (hmax) and height unit for discritization (hby).
%   Different allometric theories can be used here: the Pipe model, the Elasticity model or the WBE (Metabolic Scaling) model
%   Can also add the Perfect Plasticity Approximation to approximate the actual leaf area
%============================================================================================%

function [Bt,Bl,Bbr,Btr,Bs,Bb,Bh,Bfr,Bcr,LA,hmax,hsg,hmat,hby] = Allometry(PFTs,h,s,doheight)

%%   Populate necessary parameters and vectors
Parameters
nPFTS = size(PFTs,1);
hsg  = zeros(nPFTS,1);
hmat  = zeros(nPFTS,1);
hmax  = zeros(nPFTS,1);
hby  = zeros(nPFTS,1);
Timber = ones(size(h,1),1)*PFTs(:,1)';
LMA = ones(size(h,1),1)*PFTs(:,2)';
Seed = ones(size(h,1),1)*PFTs(:,3)';

%%  BIOMASS   %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
LA  = 1./(alpha1.^(1./beta1)).*h.^(1./beta1);% Leaf area (LA) [m^2],         based on the pipe model: LA = Bl/LMA;
Bl  = (LA.*LMA);                             % Mass leaves (Bl) [kg],        based on the pipe model: NB: h  = alpha1*LA^beta1;
Bs  = (Timber.*nc.*theta.^(-1).*LA.*h);      % Mass of sapwood (Bs) [kg],    based on the pipe model
Bb  = b.*Bs;                                 % Mass of bark (Bb) [kg],       based on the pipe model
Bh  = (Timber.*nc.*alpha2.*(LA).^(beta2));   % Mass of heartLAood (Bh) [kg], based on the pipe model
Bfr = (alpha3.*LA);                          % Mass of fine roots (Br) [kg], based on the pipe model
Bt  = Bl+Bs+Bb+Bh+Bfr;                       % Total Mass(Bt) [kg]
Br  = Bt./(2.06);                            % Biomass roots                 based on the WBE model: Niklas,2005 (Annal of Botany); Cheng & Niklas,2007 (Annal of Botany) .
Bcr = Br - Bfr;  Bcr(Bcr<0) = 0;             % Biomass coarse roots (% Scaling relationship Br = Bt/2.06 doesn't work very well for small individuals)
Babove = Bt - Br;                            % Above-Ground Biomass
Bcrown = Babove./2;                          % Crown
Bbr    = Bcrown - Bl; Bbr(Bbr<0) = 0;        % Branches
Btr    = Bcrown;      Btr(Btr<0) = 0;        % trunk

%%  HEIGHT   %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if doheight == 1
    for j = 1:nPFTS
        %   Seedling height (hsg): find root of the polynom such that Mt(seedlings)=Seed
        f  = @(x)1/(alpha1^(1/beta1))*x^(1/beta1)+ (alpha3*(1/(alpha1^(1/beta1))*x^(1/beta1))) + (Timber(j)*nc*theta.^-1*(1/(alpha1^(1/beta1))*x^(1/beta1))*x) - Seed(j) ;
        hsg(j) = fzero(f,0);   %fsolve(f,0);
        %   Height at maturity, based on biomass at maturity and seed mass
        Bmat = (1./beta7.^(1/alpha7)).*Seed(j).^(1/alpha7); % Falster et al., 2008 (Am. Nat)
        Bmat_above = Bmat.*1.06./(1+1.06);                           % Biomass above: Niklas,2005 (Annal of Botany); Cheng & Niklas,2007 (Annal of Botany) .
        Dmat = (1/beta8^(1/alpha8)).*Bmat_above.^(1/alpha8);         % Niklas, 1993 (Annal of Plant height) - scaling of plant height
        hmat(j) = beta9.*Dmat.^alpha9;                             % Niklas, 1993 (Annal of Plant height) - scaling of plant height
        hmax(j) = ceil(hmat(j).*(1-(1/50)*log(0.01)));           % Maximum height predicted from hmat considering a bang-bang reproduction strategy (solving eqn. 16 = 1 (~0.99) in Falster)
        %   Unity of size for the transition matrix (cm)
        hby(j)  = (hmax(j) - hsg(j))./s;
    end
end
