% Author: Dr. Jean-Baptiste Pichancourt, research scientist at INRAE, department of maths & numerical science, Complex systems lab., France
% jean-baptiste.pichancourt@inrae.fr 
% Year: 2020
% Licence GPLv3

function BCD = BCDLS(Physics, Biology, Forestry, Economics, Social, Linguistics, Outputs, Repmax)

%%  Inputs

%   Physics
Tmax = Physics(1,1);
Lat = Physics(2,1);
Long = Physics(3,1);
Clim = Physics(4,1);
Land = Physics(5,1);
Farea = Physics(6,1);
Nforestpatches = Physics(7,1);
Fregrowth = Physics(8,1);
Fsurroundings = Physics(9,1);
SoilElements = Physics(10:13,1);
SoilDepth = Physics(14,1);

%   Biology
Timbermin = Biology(1,1);
Timbermax = Biology(2,1);
nTimbermax = Biology(3,1);
LMAmin = Biology(4,1);
LMAmax = Biology(5,1);
nLMAmax = Biology(6,1);
Seedmin = Biology(7,1);
Seedmax = Biology(8,1);
nSeedmax = Biology(9,1);

%   Forestry
Plantmax = Forestry(1,1);
Nplant = Forestry(2,1);
ThinDivmax = Forestry(3,1);
ThinFreqmax = Forestry(4,1);
Forestry_Analysis = Forestry(5,1);
Efficient_manager =  Forestry(6,1);
Efficient_monitor =  Forestry(7,1);
silviculture = Forestry(8,1);

%   Economy
Pselltimber = Economics(1,1);
Eplanting = Economics(2:4,1);

%   Social
NumberHH = Social(1,1);
SizeHH = Social(2,1);
Access = Social(3,1);

%   Linguistics
Detectionlevelmax = Linguistics(1,1);

%%%%%%%%%%%%%%%%%%%%% CLIMATE AND LAND VARIABLES

%% Climate
Climmax = 1; % temporary fix. maximum climate scenarios populated. Variable should be deleted iff functions using Climax variable are corrected
k = Clim; %k =  mod((i - 1) + Climmax*Landmax*Detectionlevelmax,Climmax) + 1;     
    
if k == 1    %  Wetter/Hoter Climate
    
    if  exist('Clim1', 'file') == 0
      
      disp("- Creating the IPCC climate scenario (it takes time the first time)")
      [ClimSeries, MAT, MAT0, D, D0] = IPCC(Tmax, Climmax, Lat, Long, k); %	Defines the IPCC climate projections
      
    end
    
    Climate = dlmread('Clim1'); %ClimSeries(:,:,1);
    MAT = dlmread('MAT1');
    D = dlmread('D1');
    ClimAv = dlmread('ClimAv1');
    MAT0(k) = ClimAv(k,1);
    D0(k) = ClimAv(k,2);        
    
elseif k == 2    %   Dryer/Hoter Climate 
    
    if  exist('Clim2', 'file') == 0
      
      disp("- Creating the IPCC climate scenario (it takes time the first time)")
      [ClimSeries, MAT, MAT0, D, D0] = IPCC(Tmax, Clim, Lat, Long, k); %	Defines the IPCC climate projections
      
    end
    
    Climate = dlmread('Clim2'); 
    MAT = dlmread('MAT2');
    D = dlmread('D2');
    ClimAv = dlmread('ClimAv2');
    MAT0(k) = ClimAv(k, 1);
    D0(k) = ClimAv(k, 2);    
    
end    

%%   Position in the catchment (upland / lowland)    
Landmax = 1; % temporary fix. maximum climate scenarios populated. Variable should be deleted iff functions using Climax variable are corrected
l = Land; %l = mod(floor((i - 1)/(Climmax)),Landmax) + 1;      

%%   Detection level (resolution at which managers are distinguishing the species     
Detectionlevelmax = 1; % temporary fix. maximum climate scenarios populated. Variable should be deleted iff functions using Climax variable are corrected
Detectionlevel = mod(floor((i - 1) / (Climmax * Detectionlevelmax)), Detectionlevelmax) + 1;
rLMA = nLMA - Detectionlevel + 1;
PFTr = (LMAmax - LMAmin) / (rLMA - 1);          
        
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%   Call a set of parameters
Parameters;
s = 5; %s comes from Parameters: try to do better to call it from Parameters for a parfor loop

%%   Populate the Duration of management
c = clock;
ystart = c(1, 1);
yend   = ystart + max(Tmax);
tlimit = yend - ystart;

Speciesmax = nTimbermax * nLMAmax * nSeedmax;
disp(["- Max number of species in the forest:", num2str(nTimbermax * nLMAmax * nSeedmax)])  

%% Definition of specific variables and definitions per type of analysis
if Forestry_Analysis == 1
  
  Random = 0;
  Repmax = 1;
  spmax = 1;    
  nTimber = nTimbermax;
  nSeed = nSeedmax;
  nLMA = nLMAmax;
  nspecies = nTimber * nSeed * nLMA;  
  %   Populate all necessary matrices and vectors that match when, what and how many PFTs syndromes to plant
  [PFTs, nPFTS, PFTby, hsg, hmat, hbymin, smax, S, height] = Dimensions(Timbermin, Timbermax, nTimber, LMAmin, LMAmax, nLMA, Seedmin, Seedmax, nSeed); 
  %   Set up the matrix (Hmatrix) that provides all the combinations of harvesting species (1 row = 1 combination of species to thin)
  Hmatrix = ones(2^nPFTS, nPFTS);
  p = 1;
  for c = 0 : nPFTS - 1      
      Hmatrix(p + 1: 2 * p, nPFTS - c : nPFTS) = [zeros(p, 1), Hmatrix(1 : p, nPFTS - c + 1 : nPFTS)];
      p = 2 * p;
  end
  ForestryMax = size(Hmatrix, 1);  
  %  Display specific variables and definitions per type of analysis
  disp(sp)
  disp(["- Number of species in the forest:", num2str(nspecies)])  
  disp(["- Number of basic timber density classes:", num2str(nTimber)])
  disp(["- Number of seed size classes:", num2str(nSeed)])
  disp(["- Number of LMA/SLA classes:", num2str(nLMA)])  
  
elseif Forestry_Analysis == 2
  
  Random = 0;
  Repmax = 1;
  spmax = 1;
  nTimber = nTimbermax;
  nSeed = nSeedmax;
  nLMA = nLMAmax;
  nspecies = nTimber * nSeed * nLMA;
  %   Populate all necessary matrices and vectors that match when, what and how many syndromes of tree life-history traits to manage
  [PFTs, nPFTS, PFTby, hsg, hmat, hbymin, smax, S, height] = Dimensions(Timbermin, Timbermax, nTimber, LMAmin, LMAmax, nLMA, Seedmin, Seedmax, nSeed); 
  %   Set up the matrix (Hmatrix) that provides all the combinations of harvesting species (1 row = 1 combination of species to thin)
  Hmatrix = ones(2, nPFTS);  
  Hmatrix(2, :) = 0;    
  ForestryMax = size(Hmatrix, 1);    
  % Display specific variables and definitions per type of analysis
  disp(sp)
  disp(["- Number of species in the forest:", num2str(nspecies)])  
  disp(["- Number of basic timber density classes:", num2str(nTimber)])
  disp(["- Number of seed size classes:", num2str(nSeed)])
  disp(["- Number of LMA/SLA classes:", num2str(nLMA)])    
        
elseif Forestry_Analysis == 3
        
  Random = 0;
  Repmax = 1;
  spmax = 0;
  specieslistnumber = zeros(Speciesmax, 4);

  for nTimber_temp = 2 : nTimbermax   
    for  nSeed_temp = 2 : nSeedmax    
      for nLMA_temp = 2 : nLMAmax
        spmax = 1 + spmax;        
        specieslistnumber(spmax, 1) = spmax;
        specieslistnumber(spmax,2) = nTimber_temp;
        specieslistnumber(spmax,3) = nSeed_temp;
        specieslistnumber(spmax,4) = nLMA_temp;        
      endfor %nLMAmax    
    endfor % nSeedmax    
  endfor % nTimber 

elseif Forestry_Analysis == 4  

  Random = 1;
  Repmax = Repmax;
  spmax = 1; 
  nTimber = nTimbermax;
  nSeed = nSeedmax;
  nLMA = nLMAmax;
  nspecies = nTimber * nSeed * nLMA;
  %   Populate all necessary matrices and vectors that match when, what and how many PFTs syndromes to plant
  [PFTs, nPFTS, PFTby, hsg, hmat, hbymin, smax, S, height] = Dimensions(Timbermin, Timbermax, nTimber, LMAmin, LMAmax, nLMA, Seedmin, Seedmax, nSeed); 
  %   Set up the matrix (Hmatrix) that provides all the combinations of harvesting species (1 row = 1 combination of species to thin)
  Hmatrix = ones(1, nPFTS);         
  ForestryMax = size(Hmatrix, 1);
  
  % Display specific variables and definitions per type of analysis
  disp(sp)
  disp(["- Number of species in the forest:", num2str(nspecies)])  
  disp(["- Number of basic timber density classes:", num2str(nTimber)])
  disp(["- Number of seed size classes:", num2str(nSeed)])
  disp(["- Number of LMA/SLA classes:", num2str(nLMA)])   
  
endif

%%   Definition of the climate system
    if Clim == 1
      display ("- Climate scenario: wetter & hotter")
    elseif Clim == 2
      display ("- Climate scenario: dryer & hotter")
    end
    if Land == 1
      display("- Landscape scenario: upland");
    elseif Land == 2
      display("- Landscape scenario: lowland")
    end
    
%%   Dimensions of the output matrices
OUTPUT = zeros(Tmax + 1, 17, ForestryMax, spmax, Repmax);
OUTPUT_mean_y = zeros(ForestryMax, 17);
OUTPUT_se_y = zeros(ForestryMax, 17);
OUTPUT_mean_y_rep = zeros(ForestryMax, 17, spmax, Repmax));
OUTPUT_mean_delta = zeros(spmax, 17);
OUTPUT_se_delta = zeros(spmax, 17);

%%%%%%%%%%%%%%%%%%%%%%%%%%%  Start loops   %%%
for Rep = 1 : Repmax  %%  Loop replicates for sensitivity analysis  %%  
 
  for sp = 1 : spmax    %%  Loop number of species   %%
    
    %% Specific variables for analysis 3 that change with variable sp
    if Forestry_Analysis == 3     
      
       nTimber = specieslistnumber(sp, 2);
       nSeed = specieslistnumber(sp, 3);
       nLMA = specieslistnumber(sp, 4);  
       nspecies = nTimber * nSeed * nLMA;
       disp(sp)
       disp(["- Number of species in the forest:", num2str(nspecies)])  
       disp(["- Number of basic timber density classes:", num2str(nTimber)])
       disp(["- Number of seed size classes:", num2str(nSeed)])
       disp(["- Number of LMA/SLA classes:", num2str(nLMA)])   
       
       %%   Populate all necessary matrices and vectors that match when, what and how many PFTs syndromes to plant
       [PFTs, nPFTS, PFTby, hsg, hmat, hbymin, smax, S, height] = Dimensions(Timbermin, Timbermax, nTimber, LMAmin, LMAmax, nLMA, Seedmin, Seedmax, nSeed); 
       %%   Set up the matrix (Hmatrix) that provides all the combinations of harvesting species (1 row = 1 combination of species to thin)
       Hmatrix = zeros(ThinDivmax * ThinFreqmax, 2);
       for j = 1 : ThinDivmax * ThinFreqmax
           Hmatrix(j, 1) = mod(floor((j - 1) / (ThinFreqmax)), ThinDivmax) + 1 ;
           Hmatrix(j, 2) = mod(j - 1 + ThinFreqmax * ThinDivmax, ThinFreqmax) + 1 ;        
       end
       ForestryMax = size(Hmatrix, 1);           
    
    endif       

    %%   Dimensions of the Output matrix of outputs
    %MAT0 = zeros(2,1);
    %D0 = zeros(2,1);
   
    for i = 1 : ForestryMax    %%  Loop Forestry management strategies          
                
        %   Populate the specific management strategy  for i 
        m = mod(floor((i - 1) / (Climmax * Landmax * Detectionlevelmax)), ForestryMax) + 1; 
                
        %  Populate the management decisions
        if  Forestry_Analysis == 1
            
            display(Hmatrix(m, 2))
            ThinV = zeros(tlimit, 1);
            ThinV(1, 1) = 1;
            for x = 1 : floor(tlimit / f)
                if 1 + x * f < tlimit
                    ThinV(1 + x * f, 1) = Hmatrix(m, 2);
                elseif x + f >= tlimit
                    break
                end
            end
            
        elseif Forestry_Analysis == 2 || 3 || 4     
          
            Hselection = Hmatrix(m, :);            
        
        end
        
        str = regexprep(mat2str(Hmatrix(m, :)), '[^\w'']', '');    
        perc_species = sum(Hmatrix(m, :)) / size(Hmatrix(m, :), 2) * 100;    
        disp(["- Disturbance scenario ", num2str(m), ": ", num2str(perc_species), "% of species independently controlled for forestry purposes ", "(", str,")"])
        
        %%  Initial conditions at time t0
        %   Period since last harvesting of timber (initial condition)
        T = 0;
        %   Initial conditions for live trees
        N = zeros(smax + 1, nPFTS);        
        Nsnags = zeros(smax * 5, nPFTS);
        %   Initial condition for dead biomass at every size classes       
        BNdebris = zeros(smax, nPFTS, 6);
        %   state initial condition of transpiration = 0 for calculating the first leaf temperature
        Phi_net   = zeros(smax, nPFTS);
        Phi_netSg = zeros(1, nPFTS);
        %   Populate the 7 soil compartments for carbon sequestration:
        X = zeros(7,1);
        %   Initial water conditions before sequestration scenario
        [~, ~, ~, ~, ~, Water] = Soil(SoilElements);
        %   Populate the planting decisions (saplings/m2)
        if Forestry_Analysis == 1 || 2 || 4
          
            N = InitialForest2(smax + 1, nPFTS);       
            
        elseif Forestry_Analysis == 3
            
            if sum(Density,1) == 0
                N(2, :) = 0;
            elseif sum(Density,1) > 0
                Timberby    = PFTby(1, 1);
                LMAby       = PFTby(1, 2);
                Seedby      = PFTby(1, 3);
                for x=1:size(Timber, 2)
                    pTimber = (Timber(1, x) - Timbermin) / Timberby + 1;
                    pLMA = (LMA(1, x) - LMAmin) / LMAby + 1;
                    pSeed = log(Seed(1, x) / Seedmin) / log(Seedby) + 1;
                    j = round(pSeed + nSeed * (pLMA - 1) + nSeed * nLMA * (pTimber - 1));
                    N(2, j) = Density(1, x);
                end                
            end
            
        end
        
        %%  Populate some initial outputs of the forest:    
        TDmean = sum(sum(N(3 : smax + 1, :), 1) .* (PFTs(:, 1))', 2)/(sum(sum(N(3 : smax + 1, :), 1)));             
           
        for y = 1 : tlimit  %   Start annual projection of the Forest Ecosystem dynamics
            tic
            display(["Year ", num2str(y)])
            [dEdz, dEdN] = CanOpen(PFTs, N, hsg, hbymin, smax, S, s, size(PFTs, 1));
            
            if Forestry_Analysis == 1
                if y > 1
                    [Supply, Ntimber, N] = Thinning(dEdN, dEdz, N, S, Ssize, LMA, TD, PFTs, Hselection);
                endif
                
            elseif Forestry_Analysis == 2 || 3 || 4
                
                %%  Harvesting & management practices at the beginning of the year
                T = T + 1; %   Period since last harvesting of timber (add one year)           
                [Benefit, Stimber, Ntimber, N, BNdebris, Pharvest, T] = Harvesting(Access, Pselltimber, Hselection, Farea, PFTs, s, height, nPFTS, TDmean, N, BNdebris, T, Random);
                                
                %%  Post harvesting forestry practices                              
                if silviculture == 1
                  
                    [~, N, BNdebris] = Silviculture(Farea, Nforestpatches, SoilElements, dEdN, Efficient_manager, Efficient_monitor, Hselection, Eplanting, Pharvest, PFTs, s, height, N, BNdebris, Random);
                                       
                end
                
                %%  Fuelwood collection: here fuelwood comes after timber harvesting and forestry as timber extraction is considered more important for livelihoods
                %   could be reversed if fuelwood more important than timber for livelihoods.
                Hrestrictionfire = Hselection - 1;
                Hrestrictionfire(Hrestrictionfire == -1) = 1;
                [Sfuel, Nfuelalive, BNdebris, N] = ThinningFirewood(NumberHH, SizeHH, Access, Farea, Nforestpatches, PFTs, N, height, s, nLMA, rLMA, LMAmin, LMAmax, Detectionlevel, BNdebris, Hrestrictionfire);
                %display(BNdebris)
                
                %%  Total supply & details per species
                Nsupply = cat(3, Ntimber, Nfuelalive);
                Supply = [sum(sum(Stimber)), sum(sum(Sfuel))]';            
            
            end
            
            %%   Forest Community Dynamic Model (FED)           
            [AGOC, SOC, N, Nsnags, BNsnags, BNdebris, X, Water, ~, ~, Hmean, LAI, PFTmean, H, Phi_net, Phi_netSg] = FED(PFTs, Climate, MAT(y, k), MAT0(k), D(y, k), D0(k), Water, y, SoilElements, SoilDepth, N, Nsnags, BNdebris, X, height, hsg, hbymin, hmat, smax, S, s, Phi_net, Phi_netSg, l);
           
            %%  Output matrix: Forest-level variables
            OUTPUT(y+1, 1, i, sp, rep) = nspecies;  % Number of species in the forest
            OUTPUT(y+1, 2, i, sp, rep) = perc_species;  % Number of species managed in the forest
            OUTPUT(y+1, 3, i, sp, rep) = H;       %   Forest Organic Carbon: Carbon accumulated in the forest (excluding the litter that is a transitory stock)
            OUTPUT(y+1, 4, i, sp, rep) = AGOC * 10;       %   above-ground organic carbon: typically range between 25-250 Mg/ha (i.e., 2.5-25 kg/m2 * 10) with recomended value ~ 138 Mg/ha for wet forests in Asia(IPCC)
            OUTPUT(y+1, 5, i, sp, rep) = SOC * 10;       %   Soil Organic Carbon: Carbon accumulated in the Litter (conversion 10*kg/m2 = 1Mg/ha)
            if y>1
                OUTPUT(y+1, 6, i, sp, rep) = (OUTPUT(y+1, 4, i, sp, rep) - OUTPUT(y, 5, i, sp, rep));   %   Productivity = Carbon sequestration rate above ground between two consecutive years
                OUTPUT(y+1, 7, i, sp, rep) = (OUTPUT(y+1, 6, i, sp, rep) - OUTPUT(y, 5, i, sp, rep));   %   Carbon sequestration rate in the soil between two consecutive years
            endif
            OUTPUT(y+1, 8, i, sp, rep) = OUTPUT(y+1, 6, i, sp, rep) / 0.514 + OUTPUT(y+1, 7, i, sp, rep);  %  Total forest productivity = Carbon sequestration rate above ground, in the roots and in the soil between two consecutive years
            OUTPUT(y+1, 9, i, sp, rep) = PFTmean(1, 1);   %   Average timber density of trees produced in the forest [kg.m-3]
            OUTPUT(y+1, 10, i, sp, rep) = 1 / PFTmean(2, 1);   %   Average SLA=1/LMA of leaves produced by trees in the forest [m2.kg-1]
            OUTPUT(y+1, 11, i, sp, rep) = PFTmean(3, 1);  %   Average size of the seeds produced by trees the forest [kg]
            OUTPUT(y+1, 12, i, sp, rep) = LAI;   %   Leaf area index of the forest
            OUTPUT(y+1, 13, i, sp, rep) = Hmean;   %   Average hight of the forest
            OUTPUT(y+1, 14, i, sp, rep) = Water;   %   Water supply in the soil
            OUTPUT(y+1, 15, i, sp, rep) = Supply(1, 1);  %   Number of trees and seedlings thinned (reminder: the total number of sedlings per month can be very high, better to separate size classes)
            OUTPUT(y+1, 16, i, sp, rep) = Supply(2, 1);
            OUTPUT(y+1, 17, i, sp, rep) = Benefit;   %  Dollars from harvesting $
            
            toc
            
        endfor    % y = 1:ymax             
        
        OUTPUT_mean_y(i, :) =  cat(2, sum(Hmatrix(m, :)), mean(OUTPUT(:, :, i, sp, rep), 1), Hmatrix(m, :));
        OUTPUT_se_y(i, :) =  cat(2, sum(Hmatrix(m, :)), std(OUTPUT(:, :, i, sp, rep)), 1) ./ sqrt(size(OUTPUT(:, :, i, sp, rep), 1)), Hmatrix(m, :));
  
    endfor  % i = 1:ForestryMax

  endfor % sp = 1:spmax

endfor % rep

 %%%%%%%%%%%%%%%%%%%% Statistics, Plots & Save

%% General definitions
title_mean = strcat('Mean', 'Analysis', int2str(Forestry_Analysis), 'Sp', int2str(nPFTS), 'C', int2str(k), 'L', int2str(l));
title_se = strcat('S.E.', 'Analysis', int2str(Forestry_Analysis), 'Sp', int2str(nPFTS), 'C',int2str(k), 'L', int2str(l));
          
if Forestry_Analysis == 1  
  
  %% Estimation of statistics
  
  %% Save outputs 
  
  %% Plot results
  MP = cat(2, BCD(:, :, 6, :), BCD(:, :, 1, :));  % Evaluate the management performances and plot data with the Pareto Front
  EMP(MP)  % Optimization & Plot
  
elseif Forestry_Analysis == 2  
  
  %% Save outputs 
  
  %% Plot results
  
  subplot(3, 2, 1) % Fig 3A| Effect of ???? on biodiversity    
      set(gca, 'fontsize', 8)    
      errorbar(OUTPUT_mean_y(:, 2), OUTPUT_mean_y(:, 3), OUTPUT_se_y(:, 2), OUTPUT_se_y(:, 3), 'o')
      hold all    
      xlabel('Number of species in the forest')
      ylabel('level biological diversity in life-history traits (Shannon index)')
          
  subplot(3, 2, 2) % Fig 3B| Effect on  forest above ground carbon biomass
      set(gca, 'fontsize', 8)
      errorbar(OUTPUT_mean_y(:, 2), OUTPUT_mean_y(:, 4), OUTPUT_se_y(:, 2), OUTPUT_se_y(:, 4), 'o')
      hold all
      xlabel('Number of species in the forest')
      ylabel('Average annual forest above-ground carbon content [kg.m^-^2]')
      
  subplot(3, 2, 3) % Fig 3B| Timber harvesting
      set(gca, 'fontsize', 8)
      errorbar(OUTPUT_mean_y(:, 2), OUTPUT_mean_y(:, 3), OUTPUT_se_y(:, 1), OUTPUT_se_y(:, 3), 'o')
      hold all
      xlabel('Number of species in the forest')
      ylabel('Average annual economic benefit from harvesting [$.year^-^1]')
       
  subplot(3,2,4) % Fig 3C| Average basic timber density in the forest
      set(gca,'fontsize',8)            
      errorbar(OUTPUT_mean_y(:, 1), OUTPUT_mean_y(:, 8), OUTPUT_se_y(:, 1), OUTPUT_se_y(:, 8), 'o')
      hold all
      xlabel('Number of species in the forest')
      ylabel('Average timber trait (basic timber density [kg.m^-^3])')
      
  subplot(3,2,5) % Fig 3D| Average Seed size of trees in the forest
      set(gca,'fontsize',8)
      errorbar(OUTPUT_mean_y(:,1), OUTPUT_mean_y(:,9), OUTPUT_se_y(:,1), OUTPUT_se_y(:,9),'o')
      hold all
      xlabel('Number of species in the forest')
      ylabel('Average seed trait (see size [kg.m^-^3])')
      
  subplot(3,2,6) % Fig 3D| Average specific leaf area SLA of trees in the forest
      set(gca,'fontsize',8)
      errorbar(OUTPUT_mean_y(:,1), OUTPUT_mean_y(:,10), OUTPUT_se_y(:,1), OUTPUT_se_y(:,10),'o')
      hold all
      xlabel('Number of species in the forest')
      ylabel('Average leaf trait (Species Leaf Area SLA [kg.m^-^2] ')    
  
elseif Forestry_Analysis == 3  
  
  %% Estimation of statistics
  BCD_tmp = BCD;
  BCD_tmp(1, :, :, :) = []; 
  for omega = 1:size(BCD_tmp(:, :, :, :),3)
    BCDdelta(:, :, omega, sp) = (BCD_tmp(:, :, omega, sp) - BCD_tmp(:, :, size(BCD_tmp(:, :, :, :),3), sp))./BCD_tmp(:, :, size(BCD_tmp(:, :, :, :),3), sp);
  endfor

  % Results: mean 
  BCDdelta_mean_tmp = mean(BCDdelta(:, :, :, sp), 1);
  splitmean = num2cell(BCDdelta_mean_tmp, [1 2]);
  BCDdelta_mean_tmp2 = vertcat(splitmean{:});
  BCDdelta_mean_tmp2(2, :) = [];
  BCDdelta_mean(sp, :) = [BCDdelta_mean_tmp2(:, :)];

  % Results: s.e.
  BCDdelta_se_tmp =  std(BCDdelta(:, :, :, sp),1)./sqrt(size(BCDdelta(:, :, :, sp), 1));
  splitse = num2cell(BCDdelta_se_tmp, [1 2]);
  BCDdelta_se_tmp2 = vertcat(splitse{:});
  BCDdelta_se_tmp2(2, :) = [];
  BCDdelta_se(sp, :) = [BCDdelta_se_tmp2(:, :)];
      
  %% Save outputs   
  csvwrite(title_mean, BCDdelta_mean);  
  csvwrite(title_se, BCDdelta_se);

  %% Plot results    
  errorbar(BCDdelta_mean(:,1), BCDdelta_mean(:,2), BCDdelta_se(:,2),'o')
  xlabel('Number of species in the forest')
  ylabel('Difference in biodiversity level (% Shannon index H)')
  
elseif Forestry_Analysis == 4
  
  %% Estimation of statistics
  
  %% Save outputs  
  
  %% Plot results
  
endif

toc

