%============================================================================================%
%   In the decision model, the manager is faced with important decisions that need to be
%   evaluated during two phases of forest regrowth5: 1) Regeneration - whether and
%   what species to plant 2) Stand maintenance - whether, and how to maintain the stand
%   by thinning (Fig. 2). This file describes the management decision model.
%   The user  assumes first that there is a limited number of species and limited range
%   of PFTs values that is practical to find, plant and thin in forests.
%   We reduced the possible set of traits to three well-known PFTs, namely seed mass (SM),
%   leaf mass per area (LMA) and timber density (TD), which are easy to measure (i.e., soft traits)
%   and different combinations of values for these three PFTs are frequently used to characterise
%   forest species. The model assumes that species belonging to a particular are similar
%   architecturally, physiologically and demographically. It also assumes that the management
%   practitioner can choose between eleven fixed management strategies that manipulate
%   the species with different Ω during the regeneration and maintenance phases.
%   During the regeneration phase (first year), decision practitioners must decide whether
%   they allow for natural regeneration, hereafter self-recovery, or they have to initiate
%   regeneration through technical reclamation planting. Planting fast growing trees to
%   initiate reforestation can provide increased canopy or a "framework" to aid in the
%   suppression of undesirable weed species and promote shade tolerant species in the understorey.
%   We call this the "framework functional trait" (FFT) method. The FFT supports the SEH
%   (Fig. 1, Fig.2). The second method involves more complex and expensive strategies that
%   plant a maximum diversity of species, each having a unique combination omega.
%   We call this method "maximum functional diversity" (MFD). The MFD supports the CH
%   (Fig. 1, Fig 2). During the maintenance phase, practitioners have to decide whether
%   they need to accelerate or maintain productivity of the stand over time, enhance desirable
%   target species with specific sets of PFTs, or eradicate non-target invasive species with
%   other sets of traits. We consider that practitioners have the choice between five actions:
%   no thinning (j == 1); thinning the dominant species every year (j == 2);
%   or implementing various strategies of selective thinning (ST) of specific PFTs
%   to accelerate succession toward denser timber for more resistant forests (j == 3),
%   toward greater seed mass (j == 4) in order to recruit taller trees, or toward more
%   productive and shade tolerant understory leaves with higher leaf mass per area LMA (j == 5).
%   We also assume the practitioner can implement different thinning regimes f, e.g.,
%   annually (f == 1), biennially (f == 2) or every five years (f == 5).
%============================================================================================%

clear
format short G
tic
%% INPUTS

%% Type of carbon stock you want to compare with biodiversity
%           Carbon == 1: Total organic carbon in the forest (TOC)
%           Carbon == 2: Above-ground organic carbon (AGOC)
%           Carbon == 3: Litter organic carbon (LOC)
%           Carbon == 4: Soil organic carbon (SOC)
%           Carbon == 5: Total organic carbon excluding litter (TOC - LOC)
Tcarbon = 1;
%   Number of planting strategy: doing nothing 1, Framework Functional Trait (FFT), Maximum Functional Diversity (MFD
Plantmax = 6;
%   Density of planting per ha
Nplant = 1/2;
%   Thinning of dominant PFTS if canopy openness < 1%; 3 = Yes all individuals of dominant PFTS
ThinDivmax = 4;
%   Thinning frequency (1: every years, 2: every two years ...)
ThinFreqmax = 50;
%   IPCC Climate change severity: low severity (wet-hot) == 1 , high severity (arid-hot) == 2
Climmax = 2;

%% TIME AND SPACE CONDITIONS %%%%%%%%%%%%%%%%%%%%%%%%%%%

%   Give the time horizon [years] for which you want to maximize carbon
%       sequestration
Horizon  = 100;
% 	Location (lattitude / longitude)
City = 'Brisbane';
Lat    = -27.467778;
Long   = 153.027778;

%%	FOREST CONDITIONS   %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%	Unit of area at which the cobenefits are estimated [m2]
Forest(1,1) = 1;
%	Initial state of the forest to restore: SF == n: n PFTs already present in the forest (n == 0: no forest)
Forest(2,1) = 0;
%	Colonization by seeds of different PFTS from surrounding forests: SC == 0: no, SC == 1: yes.
Forest(3,1) = 1;
%	Type of soil (coarse:1, medium/coarse:2, medium:3, fine/medium:4, fine:5, organic:6)
Forest(4,1) = 3;
%   Soil depth [m]
Forest(5,1) = 3;      % usually soils are 1-10m thick

%%  UNIVERSE OF PLANT FUNCTIONAL TRAITS (PFTs), including the Range [min-max] & resolution [n] for every PFT:

% 	Stem density [kg/m3] (Maximum average stem density for a species)
Timbermin     = 400;   %300
Timbermax     = 1000;  %1000
nTimber       = 2;     %number of density classes
% 	Leaf economy [kg/m2] (Maximum average LMA for a species)
LMAmin     = 0.05;  %0.05
LMAmax     = 0.35;  %0.35
nLMA       = 2;     % number of density classes
% 	Seed size [kg] (average seed mass at maturity for a species)
Seedmin   = 10^-7; %10^-7
Seedmax   = 10^-4; %10^-3
nSeed     = 2;    % number of mass classes from Ssizemin to Ssizemax

% 	Number of subdivision of size you wish to use for the smallest species you consider
s = 5;

%%  POPULATE THE DECISIONS %%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%   Populate the Diversity index (Shannon)
CarbonBiodiv = zeros(Horizon+1,14,Plantmax,Thinmax,ThinFreqmax,Climmax);

for k = 2:Climmax
    display(k)
    %	Defines the IPCC climate projections
    [Climate,MAT,MAT0,D,D0] = IPCC(Horizon,k,City,Lat,Long);    
    %   Set up the matrix of all the combinations of harvesting species
    PFT = nLMA*nSeed*nTimber;
    Hmatrix = ones(2^PFT,PFT);
    p = 1;
    for c = 0:n-1
        Hmatrix(p+1:2*p,PFT-c:PFT) = [zeros(p,1),Hmatrix(1:p,PFT-c+1:PFT)];
        p = 2*p;
    end
    HarvDivmax = size(Hmatrix,1);
    
    for j = 4:ThinDivmax
        display(j)
        Hselection = Hmatrix(j,:);
        
        for f = 50:ThinFreqmax
            display(f)
            %	MAINTENANCE PHASE: populates the thining strategies
            ThinMonth1 = 0;
            %   Thinning frequency (every n years starting first year)
            ThinFreq = f;
            %	Synthesis of the plant functional traits in the forest
            PFTS = [Timbermin,Timbermax,nTimber,LMAmin,LMAmax,nLMA,Seedmin,Seedmax,nSeed,s]';
            
            %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% POPULATE THE CONSEQUENCES OF DECISIONS %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
            
            %   Call a set of parameters
            Parameters;
            
            %   Populate the Duration of management
            c = clock;
            ystart = c(1,1);
            yend   = ystart+max(Horizon);
            tlimit = yend-ystart;
            
            %   Populate all necessary matrices and vectors that match when, what and how many PFTs syndromes to plant
            [Carbon,PFT,TD,LMA,SM,nPFT,nPFTS,hsg,hmat,hbymin,smax,S] = Dimensions(size(Density,2),PFTS,Forest(3,1),tlimit,s);
            
            for n = 1:nPFT^nPFTS
                display(n)
                
                %   Initial water conditions before sequestration scenario
                [~,~,~,~,~,Water] = Soil(Forest(4,1));
                
                %   state initial condition of transpiration = 0 for calculating the first leaf temperature
                N = zeros(smax+1,nPFTS);
                Phi_net   = zeros(smax,nPFTS);
                Phi_netSg = zeros(1,nPFTS);
                
                %   Populate the 7 soil compartments for carbon sequestration:
                X = zeros(7,1);
                
                %   Populate the planting decisions (saplings/m2)
                if sum(Density,1) == 0
                    N(2,:) = 0;
                elseif sum(Density,1) > 0
                    Timberby    = (Timbermax-Timbermin)/(nTimber-1);
                    LMAby       = (LMAmax-LMAmin)/(nLMA-1);
                    Seedby      = exp(log(Seedmax/Seedmin)/(nSeed-1));
                    for x=1:size(Timber,2)
                        pTimber = (Timber(1,x)-Timbermin)/Timberby+1;
                        pLMA = (LMA(1,x)-LMAmin)/LMAby+1;
                        pSeed = log(Seed(1,x)/Seedmin)/log(Seedby)+1;
                        l = round(pSeed+nSeed*(pLMA-1)+nSeed*nLMA*(pTimber-1));
                        N(2,l) = Density(1,x);
                    end
                end
                
                %   Populate the thinning decision
                ThinV = zeros(tlimit,1);
                ThinV(1,1) = 1;
                for x = 1:floor(tlimit/f)
                    if 1+x*f< tlimit
                        ThinV(1+x*f,1) = j;
                    elseif x+f>= tlimit
                        break
                    end
                end
                
                %   Period since last harvesting of timber (initial condition)
                T = 0;
                %   Start annual projection of the Forest Ecosystem dynamics
                for y = 1:tlimit
                    display(y)
                    
                    %%  Local Forest Ecosystem Model to predict the next year what would be the concequences of the planting and thinning decisions on the carbon stock from alive biomass (Balive), on the carbon from dead biomass (Bdead), on the size-structured community vector (N), on the water stock in the soil (Water), on the canopy openness at height z (dEdz) and on the contribution of individuals with a given PFTs on the canopy openness (dEdN).
                    %       Forest Community Dynamic Model (FED)
                    [Balive,Bdead,N,Water,Phi_net,Phi_netSg,dEdN,dEdz,BNdead] = FED(PFT,Climate,Water,y,Forest(4,1),Forest(5,1),N,hsg,hbymin,hmat,smax,S,s,Phi_net,Phi_netSg,n,ThinMonth1,l);
                                        
                    %%  Harvesting & management practices at the begenning of the year
                    %       Period since last harvesting of timber (add one year)
                    T = T + 1;
                    %       Harvesting timber and firewwod
                    [Supply,Nharvest,T,N] = Harvesting(Social,Economics,Hselection,Detectionlevel,AfT,PFT,hbymin,smax,hsg,nPFTS,T,TDmean,BNdead,N);
                    %       Post harvesting sylvicultural practices
                    [Cost,N] = Silviculture(Efficient_manager,Efficient_monitor,Hselection,N);
                    
                    %%  Colonization by seeds from other PFTS of the surounding forest (simplification: let say potentially all the PFTS)
                    if Forest(3,1) == 1
                        for x = 1:nPFTS
                            N(1,x) = rand(1,1)*10*PFTS(7,1)/PFT(3*x,1);  % the probability of colonization is inversely proportional to the seed mass (given seed mass/number trade-off)
                        end
                    end                    
                    
                    %%  Forest Carbon Sequestration (FCS): includes Soil carbon sequestration of remaining dead material after 
                    [TOC,POC,AGOC,LOC,SOC,X] = FCS(Forest(5,1),sum(Balive),Bdead,MAT(y,1),MAT0,D(y,1),D0,X);
                    
                    %%  Structural parameters of the forest, including:
                    %       Plant functional Diversity (Shannon Index H)
                    %       Average height of the forest Hmean
                    %       Leaf area index LAI
                    A=(sum(N(3:smax+1,:),1))';
                    [Hmean,LAI,H,~] = Fstructure(PFT,N,S,hsg,hbymin,n,A,2);
                    %       Average values of LMA, Ssize and Timber density at a forest-level
                    dTimber = zeros(1,nPFTS);
                    dLMA = zeros(1,nPFTS);
                    dSeed = zeros(1,nPFTS);
                    for x = 1:nPFTS
                        dTimber(1,x) = PFT((x-1)*3+1,n);
                        dLMA(1,x) = PFT((x-1)*3+2,n);
                        dSeed(1,x) = PFT((x-1)*3+3,n);
                    end
                    Timbermean = sum(sum(N(3:smax+1,:),1).*dTimber,2)/(sum(sum(N(3:smax+1,:),1)));
                    LMAmean = sum(sum(N(3:smax+1,:),1).*dLMA,2)/(sum(sum(N(3:smax+1,:),1)));
                    Seedmean = sum(sum(N(3:smax+1,:),1).*dSeed,2)/(sum(sum(N(3:smax+1,:),1)));
                    
                    %%  Store forest level variables
                    CarbonBiodiv(y+1,1,j,f,k)= H;       %   Forest Organic Carbon: Carbon accumulated in the forest (excluding the litter that is a transitory stock)
                    CarbonBiodiv(y+1,2,j,f,k)= AGOC*10;       %   above-ground organic carbon: typically range betaeen 25-250 Mg/ha (i.e., 2.5-25 kg/m2) with recomended value ~ 138 Mg/ha for wet forests in Asia(IPCC)
                    CarbonBiodiv(y+1,3,j,f,k)= SOC*10;       %   Litter Organic Carbon: Carbon accumulated in the Litter
                    if y>1
                        CarbonBiodiv(y+1,4,j,f,k)= (CarbonBiodiv(y+1,2,j,f,k)-CarbonBiodiv(y,2,j,f,k));       %   Carbon accumulated in the humus layers 1&2
                        CarbonBiodiv(y+1,5,j,f,k)= (CarbonBiodiv(y+1,3,j,f,k)-CarbonBiodiv(y,3,j,f,k));   %   add litter which is a transitory stock
                    end
                    CarbonBiodiv(y+1,6,j,f,k)= CarbonBiodiv(y+1,4,j,f,k)/0.514 + CarbonBiodiv(y+1,5,j,f,k);         %   Biodiversity
                    CarbonBiodiv(y+1,7,j,f,k)= LAI;%   Average density of timber produced in the forest
                    CarbonBiodiv(y+1,8,j,f,k)= Timbermean;   %   Average mass per area of the leaves produced in the forest
                    CarbonBiodiv(y+1,9,j,f,k)= LMAmean;  %   Average mass of the seeds produced by the forest
                    CarbonBiodiv(y+1,10,j,f,k)=Seedmean;      %   plant functional trait syndrome thinned
                    CarbonBiodiv(y+1,11,j,f,k)=LAI;     %   Number of trees and seedlings thinned (reminder: the total number of sedlings per month can be very high, better to separate size classes)
                    CarbonBiodiv(y+1,12,j,f,k)=Nharvest;     %   Average height of the forest
                    CarbonBiodiv(y+1,13,j,f,k)=Thin;       %   Leaf area index of the forest
                    CarbonBiodiv(y+1,14,j,f,k)= Water;
                    display(H)
                    display(AGOC*10)
                    display(CarbonBiodiv(y+1,5,j,f,k))
                    
                    
                    
                end    % time t (years)
            end        % n = nPFT^nPFTS
            
            %   Create excel file to stock results
            title = strcat('ThinDiv',int2str(j),'Landscape',int2str(f),'Clim',int2str(k));
            xlswrite('EconDiv.xls',CarbonBiodiv(:,:,j,f,k),title);
            
        end % thinning frequency f
    end     % Climate scenario  k
end         % Thinning strategy j

toc

%%  Evaluate the management performances and plot data with the Pareto Front
MP = cat(2,CarbonBiodiv(:,6,:,:,:,:),CarbonBiodiv(:,Tcarbon,:,:,:,:));
EMP(MP);

