%============================================================================================%
%  CSM: Forest Carbon sequestration (FCS)
%     Estimate the annual total Soil Organic Carbon (SOC) using the Yasso
%     model developped by Liski et al., 2005 (Ecol Model)
%     NB: Use the CENTURY model (Parton et al., 1987) for estimations at a
%     monthly time scale, because formation of more labile componds matters
%     at this scale.
%     Inputs:  AGOC = scalar as the sum of carbon biomass from every trees
%                       for every plant functional trait syndrome
%              Bdead  = vector of carbon biomass accumulated in every trees
%                       for every plant functional trait syndrom
%              MAT = Mean annual temperature
%              D = Accumulated difference between Rainfall and Areal 
%                   Potential evapotranspiration during growing season
%              X = vector containing quantity of organic carbon in the
%              different soil compartments
%               
%==========================================================================

function [LOC,SOC,X] = FCS(Bdebris,MAT,MAT0,D,D0,X)

Parameters;
%   Inputs of plant material [kgC.yr-1] % Bdead = [Bl,Bbr,Bb,Btr,Bcr,Bfr]'
Bcwl = Bdebris(:,:,3) - Bdebris(:,:,4);                              % very coarse (sapwood + heartwood from trunk)
Bfwl = Bdebris(:,:,2) + Bdebris(:,:,4) + Bdebris(:,:,5);    % fine woody (branches,bark,coars roots)
Bnwl = Bdebris(:,:,1) + Bdebris(:,:,6);                 % non woody (leaves,fine roots)

%   Base-line Soil decomposition rate [yr-1]
kext_0  = 0.6;         %  0.48[0.45-0.51] for coniferous and 0.82[0.71-0.93] for hardwood
kcel_0  = 0.30;         %  0.3[0.28-0.31]
klig_0  = 0.22;         %  0.22[0.17-0.29]
khum1_0 = 0.012;        %  0.012[0.002-0.02]
khum2_0 = 0.0012;       %  0.0012[0.0008-0.0017]

%   Base-line invasion rates of woody litter by microbes [yr-1])
acwl_0  = 0.05;         %  0.03[0.028-0.032] for large tree logs (diam == 0.2-0.6m) and 0.07[0.072-0.083] for small logs (diam == 0-0.2m)
afwl_0  = 0.54;         %  0.54 [0.077-1]

%   Formation of more complex compounds in decomposition (proportion of decomposed mass) [Dimensionless 0-1]
pext  = 0.1;            %  0.2[0.1-0.3]
pcel  = 0.1;            %  0.2[0.1-0.3]
plig  = 0.1;            %  0.2[0.1-0.3]
phum1 = 0.1;            %  0.2[0.1-0.3]

%   Initial repartition of carbon concentrations within the organs in
%   the cellulose, lignine [Dimensionless 0-1]
Cnwl_ext = 0.25;        %
Cnwl_cel = 0.35;        %
Cnwl_lig = 0.4;         %
Cfwl_ext = 0.13;        %
Cfwl_cel = 0.47;        %
Cfwl_lig = 0.4;         %
Ccwl_ext = 0.03;        %
Ccwl_cel = 0.65;        %
Ccwl_lig = 0.32;        %

%   CLIMATE DEPENDANT PARAMETERS

%   Scaling parameters for climate relationships  [Dimensionless 0-1]
beta_soil  = 0.105;     %
gamma_soil = 0.00274;   %

%   Invasion rate 'ai' of woody litter 'i' by microbes
afwl  = afwl_0*(1+beta_soil*(MAT-MAT0)+gamma_soil*(D-D0));
acwl  = acwl_0*(1+beta_soil*(MAT-MAT0)+gamma_soil*(D-D0));

%   Decomposition rate  'kj' the of compartment 'j'
kext  = kext_0*(1+beta_soil*(MAT-MAT0)+gamma_soil*(D-D0));
kcel  = kcel_0*(1+beta_soil*(MAT-MAT0)+gamma_soil*(D-D0));
klig  = klig_0*(1+beta_soil*(MAT-MAT0)+gamma_soil*(D-D0));
khum1 = khum1_0*(1+0.6*beta_soil*(MAT-MAT0)+gamma_soil*(D-D0));
khum2 = khum2_0*(1+0.36*beta_soil*(MAT-MAT0)+gamma_soil*(D-D0));

%  If highly variable climates
afwl(afwl<0)=0;
afwl(afwl>1)=1;
acwl(acwl<0)=0;
acwl(acwl>0)=1;
kext(kext<0)=0;
kext(kext>1)=1;
kcel(kcel<0)=0;
kcel(kcel>1)=1;
klig(klig<0)=0;
klig(klig>1)=1;
khum1(khum1<0)=0;
khum1(khum1>1)=1;
khum2(khum2<0)=0;
khum2(khum2>1)=1;

%   POPULATES THE MATRIX FORMULATION OF YASSO 

B = [Bnwl
    Bfwl
    Bcwl];

%   Matrix of linear litter decomposition between the 7 compartiments: the parameters, and ci_j the proportion of compounds j in litter type i.
Seq = [ -afwl       0                0           0          0           0            0
    0               -acwl            0           0          0           0            0
    afwl*Cfwl_ext   acwl*Ccwl_ext    -kext       0          0           0            0
    afwl*Cfwl_cel   acwl*Ccwl_cel    0           -kcel      0           0            0
    afwl*Cfwl_lig   acwl*Ccwl_lig    kext*pext   kcel*pcel  -klig       0            0
    0               0                0           0          klig*plig   -khum1       0
    0               0                0           0          0           khum1*phum1  -khum2];

%   Allocation of carbon from the litter input (NB: B is called u in Liski
%   et al. 2005
U = [0         1       0
    0          0       1
    Cnwl_ext   0       0
    Cnwl_cel   0       0
    Cnwl_lig   0       0
    0          0       0
    0          0       0];

%   Projection of the Carbon in all the compartments
X       = X + (Seq*X + U*B);
LOC     = sum(X(1:5,:),1);       %  Total carbon in the litter (LOC)
SOC     = sum(X(6:7,:),1);%./SD;   %  Total density of carbon below ground in the humus 1&2(SOChum) per m3 of soil
%TOC     = POC + SOC;             %  Total carbon above+below per m3 of soil (TOC)
%POC     = sum(POC);              %  Total organic carbon from alive trees (TOC) including above ground and roots
%AGOC    = POC*0.514;             %  Total above-ground organic carbon from alive trees (AGOC): see Allometry.m for the scaling relationship

end