%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Estimate key mesures of the forest structure like Leaf area index (LAI),
% average height at maturity (Hmean), Shannon index of diversity (H)
%
% INPUTS:
%         
%
%         base = base of the logarithm (default=2)
%
% OUTPUTS:
%         H =    index of Shannon-Weiner
%         VarH =    variance of the index of Shannon-Weiner
%
% EXAMPLE:
%
%  From the Table 6.14 of number of individuals belonging to
%  different insect species obtained in collections using 20 light traps at
%  the Nelliampathy location, taken from the FAO Corporate Document
%  Repository: A Statistical Manual for Forestry Research
%  (http://www.fao.org/docrep/003/x6831e/X6831E14.htm)
%         A=[91,67,33,22,27,23,12,14,11,10,9,9,5,1,4,2,2,1,2,4];
%         [H,VarH]=index_SaW(A,exp(1))
%
%  Answer is:
%         H = 2.3717
%         VarH = 0.0029
%
% AUTHORS:
%
%        The Shannon index function was created by R. Hernandez-Walls and
%             A. Trujillo-Ortiz
%             Facultad de Ciencias Marinas
%             Universidad Autonoma de Baja California
%             Ensenada, Baja California
%             Mexico.
%             rwalls@uabc.edu.mx
%
%   To cite this function, this would be an appropriate format:
%   Hernandez-Walls, R.  and Trujillo-Ortiz, A. (2010).
%   index_SaW:Shannon-Wiener Index. A MATLAB file.
%   http://www.mathworks.com/matlabcentral/fileexchange/28591
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [Hmean,LAI,PFTmean,H,VarH] = Fstructure(PFTs,N,S,hbymin,hsg,s,base)

Parameters
Hmeanout = zeros(size(N,1)-2,10,size(N,2)-2);
LAIout   = zeros(size(N,1)-2,size(N,2)-2);
% Number of individuals per species (row=species and columns= stations of sample).
A=(sum(N(3:size(N,1),:),1))';
for i = 1:size(S,1)
    for sh = 2:S(i,1)   % start from 2 because fisheye is usually taken above 1m tall
        xe = [hsg(i,1) + .5*hbymin, hsg(i,1) + .5*hbymin + hbymin*(1:sh - 1)]; % mid-point rule for further integration of E
        %   Leaf area at height h
        [~,~,~,~,~,~,~,~,~,LA,~,~,~,~] = Allometry(PFTs(i,:),xe(sh),s,1);
        %   derivative of the Leaf area index (dimensionless)
        LAIout(sh,i) = (N(1+sh,i).*LA).*hbymin;
        height = xe(sh);
        qout   = zeros(sh,1);
        for z = 1:sh              %hsgold+.5*hbyold:hbyold:xe(sh)
            xxe = [hsg(i,1) + .5*((height - hsg(i,1))/sh),hsg(i,1) + .5*((height - hsg(i,1))/sh) + ((height - hsg(i,1))/sh)*(1:sh-1)]';  %  integration using mid-point rule
            
            %   Fraction (Q) of leaf area above height z  for an individual of height h
            q = (2.*n0.*(1-(xxe(z).^n0).*height.^(-n0))).*(xxe(z).^(n0-1)).*(height.^-n0);
            %   Leaf area at height z (E) for individuals of height h, for a given species
            qout(z,1) = q;
        end
        q = mean(qout);
        Havz = (height.*q.*LA.*N(sh + 1,i).* (hbymin.*((height - hsg(i,1))/sh)));   %*hby^2 because mid-point rule twice
        Hmeanout(sh,z,i) = Havz;
    end
end

%dLAIdn = sum(LAIout,1);
LAI   = sum(sum(LAIout,1),2);
Hmean = sum(sum(sum(Hmeanout,3),2),1)./LAI;

%%%%%%%%%%%%%%%%%% SHANNON-WIENER INDEX %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

if nargin < 2
    base = 2; %default log2
end
[r,c] = size(A);
warning('off','MATLAB:dispatcher:InexactMatch')
if r==1
    A=A';
end
A(isnan(A)) = 0;
n = sum(A);
Na = repmat(n,r,1);
B = A./Na.*log(A./Na)./log(base);
B(isnan(B)) = 0;
H = -sum(B);
%variance of the Shannon-Wiener index
aa = A./A;
aa(isnan(aa)) = 0;
S = sum(aa);
VarH = (sum(Na./A.*(B.^2))-(sum(B)).^2)./n+(S-1)./(2*n.^2);

%       Average values of LMA, Ssize and Timber density at a forest-level
Timbermean = sum(sum(N(3:size(N,1),:),1).*(PFTs(:,1))',2)/(sum(sum(N(3:size(N,1),:),1)));
LMAmean = sum(sum(N(3:size(N,1),:),1).*(PFTs(:,2))',2)/(sum(sum(N(3:size(N,1),:),1)));
Seedmean = sum(sum(N(3:size(N,1),:),1).*(PFTs(:,3))',2)/(sum(sum(N(3:size(N,1),:),1)));
PFTmean = [Timbermean LMAmean Seedmean]';

end % End function
