%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% INPUTS:   Horizon = Time horizon of the time series [year]
%           clim = IPCC scenarios of ClimSeries change
%           Lat = Latitude [ ]
%           Long = Longitude [ ]
%           City = Name of the major closest big city (see timeZones.m)
%
% OUTPUTS   ClimSeries = matrix containing daily values of CO2 [ppm],
%               Photosynthetic Photon Flux Density [ ], Temperature [C],
%               Rain [mm], vapor pressure [hPa], potential
%               evapotranspiration [mm]
%           MAT = vector of Mean annual temperature per year [C]
%           MAT0 = overall mean annual temperature across the 'Horizon'
%           DD = [mm]
%           DD0 = overall [mm]
%
% EXAMPLE:   [ClimSeries,MAT,MAT0,DD,DD0]  = IPCC(100,2,Lat,Long,tz)
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [ClimSeries, MAT, MAT0, D, D0]  = IPCC(Horizon, Lat, Long, Clim)

%%	DEFINE PARAMETERS, VARIABLES & MATRICES
Parameters;
climax = 1;  % define only one climate for dimensions of some vectors. To be changed and deleted if choose to define IPCC only for one climate scenario at a time
%   Time zone for the closest big city (see timeZones.m for a list of cities)
%t = timeZones();
%tz = t.zone(City);
tz = round(Long * 24 / 360);
hmax   = 24;
dmax   = [31,29,31,30,31,30,31,31,30,31,30,31];
mmax   = 12;
c = clock;
ystart = c(1,1);
yend   = ystart+max(Horizon);
ymax   = yend-ystart;
w      = 2*pi/mmax;
ClimSeries = zeros((ymax+1)*(sum(dmax))*hmax,7,climax);
MAT = zeros(ymax+1,climax);
D = zeros(ymax+1,climax);
MAT0 = zeros(climax);
D0 = zeros(climax);
PPFD   = zeros((ymax+1)*(sum(dmax))*hmax,1);
PPFDs  = zeros((ymax+1)*(sum(dmax))*hmax,1);
CO2a   = zeros((ymax+1)*(sum(dmax))*hmax,1);
Temp   = zeros((ymax+1)*(sum(dmax))*hmax,1);
Rain   = zeros((ymax+1)*(sum(dmax))*hmax,1);
VP     = zeros((ymax+1)*(sum(dmax))*hmax,1);
PET    = zeros((ymax+1)*(sum(dmax))*hmax,1);
hsr    = zeros((ymax+1)*(sum(dmax)),1);
hss    = zeros((ymax+1)*(sum(dmax)),1);
%CI     = zeros((ymax+1)*(sum(dmax))*hmax,1);
%WS     = zeros((sum(dmax))*hmax,1);
%Patm   = zeros((sum(dmax))*hmax,1);
%Tanom = -3.08 + 0.009222*CO2a;
%ys    = ystart/ystart+t-1;


%%  Start loop

    
    %   load a serie of daily climatic data from IPCC scenarios
    if Clim == 1       %  low severity (wet/hot)
        load ClimateS1.txt
        ClimSeriesS = ClimateS1;
    elseif Clim == 2   %  high severity (dry/hot) model Mk3_5 Mid
        load ClimateS2.txt
        ClimSeriesS = ClimateS2;
    end
    
    %%   [C02] IN THE ATMOSPHERE
    for y = 1:ymax+1
        for m = 1:mmax
            CO2a_l = 367.68 + 0.248*mmax*(ystart-2008+y-1);
            CO2am     = CO2a_l + 1.484*cos(w*m+mmax*(ystart-2008+y-1)-1.361)+1.535*cos(2*w*m+mmax*(ystart-2008+y-1)-4663)+0.054*m*cos(w*m+mmax*(ystart-2008+y-1)-0.78);
            for d = 1:dmax(1,m)
                for	hr = 1:24
                    CO2a((y-1)*365*hmax+(sum(dmax(1:m))-dmax(m))*hmax+(d-1)*hmax+hr,1) = CO2am;
                    ClimSeries(:,1, Clim) = CO2a;
                end
            end
        end
    end
    
    %%  RADIATION PPFD [[photon]/m2/s] rescaled per hour
    dr= 0.0174532925;   % degree to radians conversion factor
    fcirc = 360*dr; % 360 degrees in radians
    %	[slop,asp]=get_ders(dem,cs);   % calculate slope and aspect in radians using given
    %   ground reflectance coefficient (more sensible to give as input)
    r = 0.20;
    %   Slop and Asperities of the area
    slop     = 0;
    asp      = 0;
    cosSlop2 = cos(slop).*cos(slop);
    sinSlop2 = sin(slop).*sin(slop);
    term1    = ( sin(Lat).*cos(slop) - cos(Lat).*sin(slop).*cos(asp));
    term2    = ( cos(Lat).*cos(slop) + sin(Lat).*sin(slop).*cos(asp));
    term3    = sin(slop).*sin(asp);    
    
    %   Start Loop
    for y = 1:ymax+1
        for d = 1:(sum(dmax))
            Rad  = ClimSeriesS(d,3);   % MW.m-2
            %   extraterr rad at a given day
            Q0 = S0 * (1 + 0.0344*cos(fcirc*d/sum(dmax)));
            %   Sun declination dS
            dS = 23.45 * dr* sin(fcirc * ( (284+d)/sum(dmax)) ); %in radians, correct/verified
            %   Angle at sunrise
            hasr = real(acos(-tan(Lat)*tan(dS)));
            It=round(12*(1+mean(hasr(:))/pi)-12*(1-mean(hasr(:))/pi));
            
            for hr = 1:hmax
                
                %   hourangle of sun hs
                hs=hasr-(pi*hr/It);
                %   Solar angle and azimuth
                sinAlpha = sin(Lat).*sin(dS)+cos(Lat).*cos(dS).*cos(hs);
                %   Correction  using atmospheric transmissivity taub_b
                M=sqrt(1229+((614.*sinAlpha)).^2)-614.*sinAlpha; % Air mass ratio
                tau_b = 0.56 * (exp(-0.65*M) + exp(-0.095*M));
                tau_d = 0.271-0.294*tau_b; % radiation diffusion coefficient for diffuse insolation
                tau_r = 0.271+0.706*tau_b; % reflectance transmitivity
                %   Correct for local incident angle
                cos_i = (sin(dS).*term1) + (cos(dS).*cos(hs).*term2) + (cos(dS).*term3.*sin(hs));
                %   Potential incoming shortwave radiation at surface normal (equator)
                Qs = Q0 * tau_b;
                %   Qpot = potential clear sky solar radiation [W/m2]
                Qpot = Qs.* cos_i;
                Qpot(Qpot<0)=0;  % kick out negative values
                %   Diffuse radiation;
                Qd = Q0 .* tau_d .* cosSlop2./ 2.*sinAlpha;
                %   Reflectance
                Qr = Q0 .* r .* tau_r .* sinSlop2./ 2.* sinAlpha;
                Qt= Qpot + Qd + Qr;
                
                %   Total irradiance
                Qt(Qt<0)=0;
                %   Total PAR:
                PARc=(Qt/2);   %	 PAR ~ visible light [390-750nm] ~ 50% of total irradiance (Papaionnou, G., Nikolidakis, G., Asimakopoulos, D.,	and Retalis, D. 1996. Photosynthetically active radiation in Athens. Agric. For. Meteorol. 81: 287-29
                %   Photosynthetic Photon Flux Density
                PPFD((y-1)*(sum(dmax))*hmax+(d-1)*hmax+hr,1) = PARc*(1/0.2174);  % mean hourly solar irradiance per second: 1 Watt/m2 = 1 J/m2/s = 0.2174 micromol [photon]/m2/s
                PPFDs((y-1)*(sum(dmax))*hmax+(d-1)*hmax+hr,1) = Qpot/2;
                ClimSeries(:,2, Clim) = PPFD;
                ClimSeries(:,3, Clim) = PPFDs;
                %CI((y-1)*(sum(dmax))*hmax+(d-1)*hmax+hr,1)= Qt/Q0;   %  clearness index
            end
        end
    end   
    
    %%	TEMPERATURE	(max, min) [C]:    
    %   Sunset/sunrise hours
    for y = 1:ymax+1
        for m = 1:12
            for d = 1:dmax(1,m)
                yr = ystart+y-1;
                date = [yr m d];
                [rs,~,~,~,~,r] = suncycle(Lat,Long,date,2880);
                %[hsrgsm,minsrgs,hssgsm] = sunrise(m,d,yr,Lat,Long);
                sr = round(rs(1,1))+tz; %+ round(Long/15);    % time zone UTC based on longitude
                ss = round(rs(1,2))+tz; %+ round(Long/15);    % time zone UTC based on longitude
                sr(sr > 24) = sr-24;
                ss(ss > 24) = ss-24;
                hsr((y-1)*365+(sum(dmax(1:m))-dmax(m))+d,1)= sr;
                hss((y-1)*365+(sum(dmax(1:m))-dmax(m))+d,1)= ss;
            end
        end
    end
    
    for d = 1:365*(ymax+1)
        Tmax = ClimSeriesS(d,4);   % Maximum temperature [C]
        Tmin = ClimSeriesS(d,5);   % Minimum temperature [C]
        TminN= ClimSeriesS(d+1,5);   % Minimum temperature of the next day [C]
        %	Hourly temperature using modifyied Parton Logan model:   Cesaraccio C, Spano D, Duce P, Snyder RL. 2001. An improved model for determining degree-day values from daily temperature data. Int J Biometeorol 45:161�9
        Tss   = Tmax-0.39*(Tmax-TminN);
        hsrf  = hsr(d,1)+24;  % sunrise hour of the following day
        htmax = hss(d,1)-4;  % time of the max temperature
        b     = (TminN-Tss)/(sqrt(hsrf-hss(d,1)));
        
        for	hr = 1:24
            if  hr<=hsr(d,1)
                Th = Tss + b*sqrt(hr-(hss(d,1)-24));
            elseif hr<=htmax %hr>hsr(d,1) &&
                Th = Tmin + (Tmax-Tmin)*((hr-hsr(d,1))/(htmax-hsr(d,1))*pi/2);
            elseif hr <=hss(d,1) %hr>htmax &&
                Th = Tss + (Tmax-Tss)*sin(pi/2+(hr-htmax)/4*pi/2);
            elseif hr <=24 %hr>hss &&
                Th = Tss + b*sqrt(hr-hss(d,1));
            end
            Temp((d-1)*hmax+hr,1) = Th;
            ClimSeries(:,4, Clim) = Temp;
        end	% hour
    end	% day
    
    %%   RAIN [mm]
    for d = 1:366*(ymax+1)
        for	hr = 1:24
            Rain((d-1)*hmax+hr,1) = ClimSeriesS(d,6)/24;
            ClimSeries(:,5, Clim) = Rain;
        end	% hour
    end
    
    %%   Vapor pressure [hPa]
    for d = 1:366*(ymax+1)
        for	hr = 1:24
            VP((d-1)*hmax+hr,1) = ClimSeriesS(d,8);
            ClimSeries(:,6, Clim) = VP;
        end
        
    end
    
    %%   Potential evapotranspiration (areal-PET and not point-PET, otherwise scale)
    for d = 1:366*(ymax+1)
        for	hr = 1:24
            PET((d-1)*hmax+hr,1) = ClimSeriesS(d,7)/24;   % Evaportranspiration
            ClimSeries(:,7, Clim) = PET;
        end
    end
    
    
    %%  Create Final output
    
    for y = 1:ymax+1
        MAT(y,1)   = mean(Temp((y-1)*366*24+1:y*366*24,1));
        dd = sum(Rain((y-1)*366*24+1:y*366*24,1)) - sum(PET((y-1)*366*24+1:y*366*24,1))*1.08;
        % (only the negative values of this difference are used, since the positive values indicate the
        %  no-drought effect, and thus favourable moisture conditions for decomposition
        %  Brisbane: ~ 1000mm rain, ~ 1500mm for areal-PET, 1900mm for point-PET
        dd(dd>0) = 0; %>0 therefore no drought so 0
        D(y,1, Clim) = dd;
    end
    
    MAT0(Clim)      = mean(Temp);
    D0(Clim)        = mean(dd);      % or -400 mm (Tropics: all year) PotentialEvap = 1.08*PanEvap (or *0.75) in Australia (Kirono et al., 2009 (INTERNATIONAL JOURNAL OF CLIMATOLOGY) - Pan-evaporation measurements and Morton-point potential evaporation estimates in Australia: are their trends the same
    D0(D0>0)  = 0;    %>0 therefore no drought so 0
    
    %%  Create file outputs to avoid recalculating this.
    ClimAv = cat(2,MAT0,D0);
    title = strcat('Clim',int2str(Clim));
    dlmwrite(title,ClimSeries(:,:, Clim));
    title2 = strcat('MAT',int2str(Clim));
    dlmwrite(title2,ClimSeries(:,:, Clim))
    title3 = strcat('D',int2str(Clim));
    dlmwrite(title3,ClimSeries(:,:, Clim))
    title4 = strcat('ClimAv',int2str(Clim));
    dlmwrite(title4,ClimAv)










