%============================================================================================%
%   Predicts how linguistic erosion is affecting plant functional
%   diversity (PFD), above ground organic carbon sequestration rate (AGOC),
%   the soil organic carbon sequestration rate (SOC), and the Total organic
%   carbon sequestration rate (TOC).
%   Linguistic diversity is defined as the number of words (with associated
%   perception cognitions) to describe shades of green and yellow/green on
%   a 1250 matt Munsell color chips:
%   http://cs.joensuu.fi/~spectral/databases/download/munsell_spec_matt.htm
%   the number of words used by a given language are described in the World
%   Color Survey (Kay, Berlin, Maffi, Merrifield, Cook. The World Color
%   Survey. Stanford: CSLI, July 2009).
%============================================================================================%

clear
format short G
tic
%% INPUTS

%% GEOGRAPHIC CONTEXT
%   Give the time horizon [years] for which you want to maximize carbon
%       sequestration
Horizon  = 100;
% 	Location (lattitude / longitude)
    Lat    = -27.467778;
    Long   = 153.027778;
%   Direction from Greenwich meridian: -1: West, +1: Est
    Direction = 1; 

%%  CLIMATE & LANDSCAPE CONTEXTS
%   IPCC Climate change severity: low severity (wet-hot) == 1 , high severity (arid-hot) == 2, 
Climmax = 1;
%   Landscape context: upland == 1, lowland (water saturated) == 2
Landmax = 2;

%%	FOREST CONDITIONS
%	Unit of area at which the cobenefits are estimated [m2]
Forest(1,1) = 100000;
%	Initial state of the forest to restore: SF == n: n PFTs already present in the forest (n == 0: no forest)
Forest(2,1) = 0;
%	Colonization by seeds of different PFTS from surrounding forests: SC == 0: no, SC == 1: yes.
Forest(3,1) = 1;
%	Type of soil (coarse:1, medium/coarse:2, medium:3, fine/medium:4, fine:5, organic:6)
Forest(4,1) = 3;
%   Soil depth [m]
Forest(5,1) = 3;      % usually soils are 1-10m thick
%   Whether or not the forest needs to be restored/regrew: Y=1, N=0
Forest(6,1) = 0;
%   Call Initial forest structure matrix
InitialForest;
%%  UNIVERSE OF PLANT FUNCTIONAL TRAITS (PFTs), including the Range [min-max] & resolution [n] for every PFT:
% 	Stem density [kg/m3] (Maximum average stem density for a species)
Timbermin     = 300;   %300
Timbermax     = 1000;  %1000
nTimber       = 8;     %number of density classes
% 	Leaf economy [kg/m2] (Maximum average LMA for a species)
LMAmin     = 0.05;  %0.05
LMAmax     = 0.4;  %0.7
nLMA       = 8;     % number of density classes
% 	Seed size [kg] (average seed mass at maturity for a species)
Seedmin   = 10^-7; %10^-7
Seedmax   = 10^-5; %10^-3
nSeed     = 3;    % number of size classes from Ssizemin to Ssizemax
% 	Number of subdivision of size you wish to use for the smallest species you consider
s = 5;

%%  SILVICULTURAL PRACTICES
%   Number of planting strategy: doing nothing 1, Framework Functional Trait (FFT), Maximum Functional Diversity (MFD
    Plantmax = 6;
%   Density of planting per ha
    Nplant = 1/2;
%   Thinning of dominant PFTS if canopy openness < 1%; 3 = Yes all individuals of dominant PFTS
    Thinmax = 5;
%	Thinning the first year: 1=yes, 0=no
    ThinMonth1 = 0;
    
%%  SOCIAL SYSTEM
%   Number of household that have access to this patch of forest
    Social(1,1) = 1;
%   Average Size of household (number of members per households)
    Social(2,1) = 5; 
%   Average access rate per household (no access: 0, open access:1)
    Social(3,1) = 1; 
%%  Linguistic system
    Langmax = 5;
%% OUTPUTS
%           Carbon == 1: Total organic carbon in the forest (TOC)
%           Carbon == 2: Above-ground organic carbon (AGOC)
%           Carbon == 3: Litter organic carbon (LOC)
%           Carbon == 4: Soil organic carbon (SOC)
%           Carbon == 5: Total organic carbon excluding litter (TOC - LOC)
Tcarbon = 1;

%%  START LOOPS
%   Populate the Diversity index (Shannon)
CarbonBiodiv = zeros(Horizon+1,14,Landmax,Climmax,Langmax);

for Lang = 5:Langmax
    rLMA = nLMA - Lang + 1;
    display(Lang)
%%  Start loop for climate
for k = 1:Climmax
    display(k)
    %	Defines the IPCC climate projections
    [Climate,MAT,MAT0,D,D0] = IPCC(Horizon,k,Direction,Lat,Long);

    %%  Start loop for position of forest in the landscape/catchement
    for l = 2:Landmax
        display(l)        
            
        %	Synthesis of the plant functional traits in the forest
            PFTS = [Timbermin,Timbermax,nTimber,LMAmin,LMAmax,nLMA,Seedmin,Seedmax,nSeed,s]';        
        %   Call a set of parameters
            Parameters;        
        %   Populate the Duration of management
            c = clock;
            ystart = c(1,1);
            yend   = ystart+max(Horizon);
            tlimit = yend-ystart;        
        %   Populate all necessary matrices and vectors that match when, what and how many PFTs syndromes to plant
            [Carbon,PFT,TD,LMA,SM,nPFT,nPFTS,hsg,hmat,hbymin,smax,S,height] = Dimensions(nTimber*nSeed*nLMA,PFTS,Forest(3,1),tlimit,s);
                    
        %%   Start loop of plant functional traits        
        for n = 1:nPFT^nPFTS            
                      
            %   Define Initial Forest:                
                N = Nzero;                               
            %   Initial water conditions before sequestration scenario
                [~,~,~,~,~,Water] = Soil(Forest(4,1));                
            %   State initial condition of transpiration = 0 for calculating the first leaf temperature
                Phi_net   = zeros(smax,nPFTS);
                Phi_netSg = zeros(1,nPFTS);                
            %   Populate the 7 soil compartments for carbon sequestration:
                X = zeros(7,1);
                
            %%   Start annual projection of the Forest Ecosystem dynamics
            for y = 1:tlimit
                display(y)                
                %   Colonization by seeds from other PFTS of the surounding forest (simplification: let say potentially all the PFTS)
                    if Forest(3,1) == 1
                        for x = 1:nPFTS
                        N(1,x) = rand(1,1)*10*PFTS(7,1)/PFT(3*x,1);  % the probability of colonization is inversely proportional to the seed mass (given seed mass/number trade-off)
                        end
                    end 
                    [Supply,Nthinned,N] = ThinningFirewood(Social,Forest(1,1),PFT,N,height,nLMA,rLMA,LMAmin,LMAmax,Lang); 
                %	Call the Forest Ecosystem Dynamic Model (FED) to predict the next year what would be the concequences of the planting and thinning decisions on the carbon stock from alive biomass (Balive), on the carbon from dead biomass (Bdead), on the size-structured community vector (N), on the water stock in the soil (Water), on the canopy openness at height z (dEdz) and on the contribution of individuals with a given PFTs on the canopy openness (dEdN).
                    if Landmax == 2
                        Water = 10000000;
                    end
                    [Balive,Bdead,N,Water,Phi_net,Phi_netSg,dEdN,dEdz] = FED(PFT,Climate,Water,y,Forest(4,1),Forest(5,1),N,hsg,hbymin,hmat,smax,S,s,Phi_net,Phi_netSg,n,ThinMonth1,l);
                
                %   Calculate structural parameters of the forest, including:
                    %   Plant functional Diversity (Shannon Index H)
                    %   Average height of the forest Hmean
                    %   Leaf area index LAI
                    A=(sum(N(3:smax+1,:),1))';
                    [Hmean,LAI,H,~] = Fstructure(PFT,N,S,hsg,hbymin,n,A,2);                
                %   Call the model of Forest Carbon Sequestration (FCS)
                    [TOC,POC,AGOC,LOC,SOC,X] = FCS(Forest(5,1),sum(Balive),Bdead,MAT(y,1),MAT0,D(y,1),D0,X);                
                %   Calculate the average values of LMA, Ssize and Timber density at a forest-level
                    dTimber = zeros(1,nPFTS);
                    dLMA = zeros(1,nPFTS);
                    dSeed = zeros(1,nPFTS);
                    for x = 1:nPFTS
                        dTimber(1,x) = PFT((x-1)*3+1,n);
                        dLMA(1,x) = PFT((x-1)*3+2,n);
                        dSeed(1,x) = PFT((x-1)*3+3,n);
                    end
                    Timbermean = sum(sum(N(3:smax+1,:),1).*dTimber,2)/(sum(sum(N(3:smax+1,:),1)));
                    LMAmean = sum(sum(N(3:smax+1,:),1).*dLMA,2)/(sum(sum(N(3:smax+1,:),1)));
                    Seedmean = sum(sum(N(3:smax+1,:),1).*dSeed,2)/(sum(sum(N(3:smax+1,:),1)));                    
                %   What to thin at the end of the year
                    %[Supply,N] = ThinningFirewood(Social,N,TD,PFT,Forest(1,1),height);                    
                    %[Thin,Nthin,N] = Thinning(dEdN,dEdz,N,S(:,n),Seedmean,LMAmean,Timbermean,PFT(:,n),j);                
                %   Store forest level variables
                    CarbonBiodiv(y+1,1,l,k,Lang)= H;       %   Forest Organic Carbon: Carbon accumulated in the forest (excluding the litter that is a transitory stock)
                    CarbonBiodiv(y+1,2,l,k,Lang)= AGOC*10;       %   above-ground organic carbon: typically range betaeen 25-250 Mg/ha (i.e., 2.5-25 kg/m2) with recomended value ~ 138 Mg/ha for wet forests in Asia(IPCC)
                    CarbonBiodiv(y+1,3,l,k,Lang)= SOC*10;       %   Litter Organic Carbon: Carbon accumulated in the Litter
                    if y>1
                        CarbonBiodiv(y+1,4,l,k,Lang)= (CarbonBiodiv(y+1,2,l,k,Lang) - CarbonBiodiv(y,2,l,k,Lang));       %   Carbon accumulated in the humus layers 1&2
                        CarbonBiodiv(y+1,5,l,k,Lang)= (CarbonBiodiv(y+1,3,l,k,Lang) - CarbonBiodiv(y,3,l,k,Lang));   %   add litter which is a transitory stock
                    end                
                    CarbonBiodiv(y+1,6,l,k,Lang)= CarbonBiodiv(y+1,4,l,k,Lang)/0.514 + CarbonBiodiv(y+1,5,l,k,Lang);         %   Biodiversity
                    CarbonBiodiv(y+1,7,l,k,Lang)= LAI;%   Average density of timber produced in the forest
                    CarbonBiodiv(y+1,8,l,k,Lang)= Timbermean;   %   Average mass per area of the leaves produced in the forest
                    CarbonBiodiv(y+1,9,l,k,Lang)= LMAmean;  %   Average mass of the seeds produced by the forest
                    CarbonBiodiv(y+1,10,l,k,Lang)= Seedmean;      %   plant functional trait syndrome thinned
                    CarbonBiodiv(y+1,11,l,k,Lang)= LAI;     %   Number of trees and seedlings thinned (reminder: the total number of sedlings per month can be very high, better to separate size classes)
                    CarbonBiodiv(y+1,12,l,k,Lang)= Nthinned;     %   Average height of the forest
                    CarbonBiodiv(y+1,13,l,k,Lang)= Supply;       %   Leaf area index of the forest
                    CarbonBiodiv(y+1,14,l,k,Lang)= Water;
                    display(H)
                    display(AGOC*10)
                    display(CarbonBiodiv(y+1,5,l,k,Lang)) 
                    %display(CarbonBiodiv)
                    
            end    %% time t (years)
        end        %% n = nPFT^nPFTS
            CarbonBiodiv(:,:,l,k,Lang)
        %   Create excel file to stock results
            title = strcat('Language',int2str(Lang),'IPCC',int2str(k),'Landscape',int2str(l));
            xlswrite('LingDiv.xls',CarbonBiodiv(:,:,l,k,Lang),title);       
           
    end %% Landscape scenario f
end     %% Climate scenario  k
end
toc

%%  Evaluate the management performances and plot data with the Pareto Front
MP = cat(2,CarbonBiodiv(:,6,:,:,:),CarbonBiodiv(:,Tcarbon,:,:,:));
EMP(MP);

