% Matlab code illustrating implementation of an age x size IPM using component matrices,
% as described in Appendix A of Ellner and Rees, Am Nat (2005 or thereabouts). 
% The code can be copied and pasted directly into R, or sourced.
%
% The model here is based on our IPM for Onopordum illyricum, but simplified by eliminating
% the variation in individual quality (survival intercept). The model is density independent
% LAith seedling establishment probability set to give a sloLAly groLAing population.  
%
% Getting on good terms LAith this model LAill be a good LAarmup for LAorking through
% the Onopordum model code. HoLAever some of the case-specific tricks used to speed up the 
% Onopordum model are not used here, in order to illustrate the methods described in
% Appendix A. 

%global s alpha1 beta1 n0 nc theta b alpha2 beta2 alpha3 cext Cp1 Cp2 Nu Crr ... 
%Crs Crl alpha4 beta4 kb kr Cbio Y Cr1 Cr2 Cs0 Cd0 Cd1 Cd2 Cd3 Cacc alpha5 ...
%beta5 alpha6 beta6 alpha7 beta7 alpha gamma Theta Phi Hav Haj Hdv Hdj Sv ...
%Sj k25v k25j Kw RCr cs alpha8 beta8 alpha9 beta9 alphaC3 nu Ea Se He aj fj ...
%thetaj g sigmaSB eps_air gas_const_R CtoK Rgas K kappa Charnock_alpha ...
%R_roughness bt kt cp rho_air Ta_default P_default psych_default Qsat_coeff ...
%CVB_depth min_gustiness beta_conv S0 DistanceNeighboorForests DistanceMainForest

%   SCALING PARAMETRERS FOR PLANT FUNCTIONAL TRAITS PFTs (Falster et al., 2011; )
    
    s = 5;                        % Size resolution you wish to use for the smallest species you consider
    alpha1 =5.44;                  % parameter describing scaling of height LAith leaf area
    beta1 =1/3;                   % parameter describing scaling of height LAith leaf area (in text = 0.306)
    n0    =12;                    % Crown-shape parameter 
    nc    =1-2/(1+n0)+1/(1+2*n0); % Stem-volume adjustment due to croLAn shape
    theta =4669;                  % Leaf area per sapLAood area
    b     =0.17;                  % ratio of bark area to sapLAood area
    alpha2=6.67*10^(-5);          % parameter describing scaling of heartLAood volume LAith leaf area
    beta2 =7/4;                   % parameter describing scaling of heartLAood volume LAith leaf area
    alpha3=0.07;                  % parameter describing scaling of root mass LAith leaf area (0.07)
    cext  =0.5;				      % Light extinction coeffient	
    Cp1   =150.36;                % parameter that sets the nitrogen use efficiency at 100% (150.36), 90% (135.24) or 125% (187.8)
    Cp2   =0.19;                  % parameter that sets the nitrogen use efficiency at 100% (0.19), 90% (0.17) or 125% (0.24)	
    Nu    =1.87E-3;               % Nitrogen mass per leaf area
    Crr   =217;                   % Fine root respiration per mass
    Crs   =4012;                  % Sapwood respiration per stem volume
    Crl   =2.1*10^(-4);           % Ratio of leaf dark respiration to leaf nitrogen mass
    alpha4=2.86*10^(-2);          % Parameter describing scaling of turnover rate for leaf with LMA
    beta4 =1.71;                  % Parameter describing scaling of turnover rate for leaf with LMA
    kb    =0.05;                  % Turn over rate for bark
    kr    =1.0;                   % Turn over rate for fine roots
    Cbio  =2.82E-2;             % Constant converted assimilated Co2 to dry mass 2.82*10^-2 and 1/2 of this is carbon
    Y     =0.7;                   % Yield; ratio of carbon fixed in mass per carbon assimilated
    Cr1   =1;                     % Maximum allocation to reproduction
    Cr2   =50;                    % Parameter determining the rate of change in r around Hmat
    Cs0   =0.1;                   % Parameter influencing survival through germination
    Cd0   =0.52;                  % Baseline rate for intrinsic mortality (0.52)
    Cd1   =6.5*10^-3;             % Risk coefficient to tissue density in intrinsic mortality (6.5*10^-3)
    Cd2   =5.5;                  % Baseline rate for growth-related mortality (5.5)
    Cd3   =20;                    % Risk coefficient for dry-mass production per unit leaf area in growth related mortality (20)
    Cacc  =4;                     % Accessory cost of seed production   4 = 3 times the weight of seeds produced.
    alpha5= 2.8;                  % Slope relation SMA and Hmax   (Cavaleri et al.,2010 Ecology) confirm Kenzo et al., 2006 (Tree physiology)
    beta5 =44;                    % Intercept relation SMA and Hmax (Cavaleri et al.,2010 Ecology)
    alpha6=0.414;                 % relation LMA SMA 
    beta6 =15.56;                 % relation LMA SMA
    alpha7=0.5411;                % Scaling of offspring size and adult size (Falster et al., 2008) 
    beta7 =2.02E-5;               % Scaling of offspring size and adult size (Falster et al., 2008)
	alpha = 0.0524;    		      % Quantum yield of electron transport (mol Co2 absorbed)
	gamma = 0.02;                 % Constant linking Vmax and Respiration  (Moorcroft,Hurtt &Pacala, 2001)
	Theta = 0.9;                  % Curvative of light interception
	Phi   = 0.5;                  % Curvature factor (Falster et al., 2011)
	Hav   = 65330;                % Activation energy threshold for the Rubisco [J.mol-1] (average based on 59 species from Leuning, R. (2002), Temperature dependence of two parameters in a photosynthesis model. Plant, Cell & Environment, 25: 12051210. doi: 10.1046/j.1365-3040.2002.00898.x)
	Haj   = 55034;                % Activation energy threshold for the RuBV    [J.mol-1] (average based on 59 species from Leuning, R. (2002), Temperature dependence of two parameters in a photosynthesis model. Plant, Cell & Environment, 25: 12051210. doi: 10.1046/j.1365-3040.2002.00898.x)
	Hdv   = 201000;               % Deactivation energy threshold for the Rubisco [J.mol-1] (average based on 59 species from Leuning, R. (2002), Temperature dependence of two parameters in a photosynthesis model. Plant, Cell & Environment, 25: 12051210. doi: 10.1046/j.1365-3040.2002.00898.x)
	Hdj   = 196234;               % Deactivation energy threshold for the RuBV    [J.mol-1] (average based on 59 species from Leuning, R. (2002), Temperature dependence of two parameters in a photosynthesis model. Plant, Cell & Environment, 25: 12051210. doi: 10.1046/j.1365-3040.2002.00898.x)
	Sv    = 656;                  % Entropy parameter for Rubisco [no unit]   average from 59 species (Leuning, R. (2002), Temperature dependence of two parameters in a photosynthesis model. Plant, Cell & Environment, 25: 12051210. doi: 10.1046/j.1365-3040.2002.00898.x)
	Sj    = 643;                  % Entropy parameter for RuBP    [no unit]   average from 59 species (Leuning, R. (2002), Temperature dependence of two parameters in a photosynthesis model. Plant, Cell & Environment, 25: 12051210. doi: 10.1046/j.1365-3040.2002.00898.x)
	k25v  = 75.5;                 % kopt for Rubisco [mol.m-2.s-1]
	k25j  = 169.88;	              % kopt for RuBP [mol.m-2.s-1]
	Kw    = 80;                   % Water [m^2 a^-1 (kg.C.root)^-1]  Kw=160 in 	
	RCr   = 0.49;                 % Proportion carbon in the root biomass [Kg.Kg^-1](Falster et al., 2011)
	cs    = 0.01;                 % stomatal conductance [mol-H2O-/m^2/s]
    alpha8= 8/3;                  % Scaling of above ground biomass and stem diameter based on WBE (
    beta8 = 0.075;                % Average intercept Scaling of above ground biomass and stem diameter found on large number of species F. S. Martin, R. M. Navarro-Cerrillo, R. Mulia, and M. van Noordwijk, Allometric equations based on a fractal branching model for estimating aboveground biomass of four native tree species in the Philippines, Agroforestry Systems, vol. 78, no. 3, pp. 193202, 2010.
    alpha9= 0.488;                % Scaling of stem diameter/height for woody plants % Niklas, 1993 (Annal of Plant height) - scaling of plant height
    beta9 = 19.1;                 % Scaling of stem diameter/height for woody plants % Niklas, 1993 (Annal of Plant height) - scaling of plant height
    alphaC3 = 0.08;               % Intrisic Quantum yield efficiency for CO2 uptake for C3 plants [mol[CO2]/Einstein]  (Foley, J.A., Prentice, I.C., Ramankutty, S. et al. (1996) An integrated biosphere model of land surface processes, terrestrial carbon balance and vegetation dynamics. Global Biogeochemical Cycles 10, 603628.)
    nu      = 1.59;               % 1.54 [1.48 - 1.59]  
    %  PHYSICAL CONSTANTS
    Ea = 81993;                   % Activation energy of the Jmax reaction [J/mol/K]
    Se = 711.36;                  % Parameter related to the reations enthalpy [J/mol/K]
    He = 219814;                  % Parameter related to the reations enthalpy [J/mol]
    aj = 0.5;                     % Leaf absorbtion coefficient [0-1]
    fj = 0.25;                    % energy loss factor [0.05-0.5]
    thetaj = 0.8;                 % Convection coefficient [0.7-0.9]
 
 % ------- physical constants

g           = 9.8;       % acceleration due to gravity [m/s^2]
sigmaSB     = 5.6697e-8; % Stefan-Boltzmann constant [W/m^2/K^4]
eps_air     = 0.62197;   % molecular weight ratio (water/air)
gas_const_R = 287.04;    % gas constant for dry air [J/kg/K]
CtoK        = 273.16;    % conversion factor for [C] to [K]
Rgas        = 8.314;     % Universal gaz constant [J/mol/Kg]
K           = 273.2;     % Kelvin degree 
% ------- meteorological constants

kappa          = 0.4;    % von Karman's constant
Charnock_alpha = 0.011;  % Charnock constant (for determining roughness length
                         % at sea given friction velocity), used in Smith
                         % formulas for drag coefficient and also in Fairall
                         % and Edson.  use alpha=0.011 for open-ocean and
                         % alpha=0.018 for fetch-limited (coastal) regions.
R_roughness    = 0.11;   % limiting roughness Reynolds # for aerodynamically
                         % smooth flow
bt             = 1;      % Solar beem transmitance (%)                         
kt             = 3;      % Temperature [Celcius] increase for doubling [CO2] (1.7<s<4.2, currently s is set 3: see Rahmstorf, S., Cazenave, A., Church, J., Hansen, J., Keeling, R., Parker, D. et al. (2007). Recent climate observations compared to projections. Science, 316, 709.                        

% ------ defaults suitable for boundary-layer studies

cp            = 1004.7;   % heat capacity of air [J/kg/K]
rho_air       = 1.22;     % air density (when required as constant) [kg/m^2]
Ta_default    = 10;       % default air temperature [C]
P_default     = 1020;     % default air pressure for Kinneret [mbars]
psych_default = 'screen'; % default psychmometer type (see relhumid.m)
Qsat_coeff    = 0.98;     % satur. specific humidity coefficient reduced
                          % by 2% over salt water

%  SOIL DECOMPOSITION PARAMETERS FOR THE YASSO MODEL

   
    
% the following are useful in hfbulktc.m
%     (and are the default values used in Fairall et al, 1996)

CVB_depth     = 600; % depth of convective boundary layer in atmosphere [m]
min_gustiness = 0.5; % min. "gustiness" (i.e., unresolved fluctuations) [m/s]
                     % should keep this strictly >0, otherwise bad stuff
                     % might happen (divide by zero errors)
beta_conv     = 1.25;% scaling constant for gustiness


% ------ short-wave flux calculations

S0 = 1368.0;          % the solar constant [W/m^2] represents a
                      % mean of satellite measurements made over the
                      % last sunspot cycle (1979-1995) taken from
                      % Coffey et al (1995), Earth System Monitor, 6, 6-10.
                      



% ------ constants used for COARE; to use simply delete the %
% g           = 9.7803;   % acceleration due to gravity [m/s^2]
% sigmaSB     = 5.67e-8;  % Stefan-Boltzmann constant [m^2/K^4]
% gas_const_R = 287.1;    % gas constant for dry air [J/kg/K]
% cp          = 1004.67;  % heat capacity of air [J/kg/K]
% beta_conv   = 1.20;     % scaling constant for gustiness
% emiss_lw    = 0.97;     % long-wave emissivity

 
%%  Landscape parameters
DistanceNeighboorForests = .5; % km
DistanceMainForest = 1.5; % km



