%============================================================================================%
% IVM: INDIVIDUAL VITAL MODEL
%      Estimate the vital rates from photosynthetic absorbtion of the trees
%==========================================================================


function [Ssg,Sk,Gxy,Fk,Tl,Tfr,Tb,Wup,Phi_net] = PhysioDemo(dEdz,Climate,Water,PFTs,N,smax,n,Phi_net,hsg,hmat,hbymin,sg,s)

%   Populate necessary parameters and vectors of initial conditions
Parameters;
Ssg  = zeros(1,n);
Sk  = zeros(smax,n);
Gxy = zeros(smax,n);
Fk  = zeros(smax,n);
Tl  = zeros(smax,n);
Tfr  = zeros(smax,n);
Tb  = zeros(smax,n);
Wup  = zeros(smax,n);
P   = zeros(smax,n);
CO2 = Climate(:,1);
Qt  = Climate(:,2);
Qts = Climate(:,3);
Tc  = Climate(:,4);
rain = mean(Climate(:,5))./3600;  %average rainfall per sec within a month
VPa = Climate(:,6);
t = size(Tc,1);
STD = PFTs(:,1)';
LMA = PFTs(:,2)';
Ssize = PFTs(:,3)';

%
if sg ==0       %  Deal with trees: Size classes for all the PFTS present in the forest (mid-point rule)
    vec = ones(n,1)*(hbymin.*[1:smax-1]);
    hsgt = (hsg(:,1) + .5.*hbymin)*ones(1,smax);
    hsize = cat(2,zeros(n,1),vec);
    height  = (hsgt + hsize)';
elseif sg == 1   %  Deal with seedlings: Size classes for all the PFTS present in the forest (mid-point rule)
    height  = hsg';
end


%   	Populate biomass for all size classes
[~,Bl,~,~,~,Bb,~,Bfr,~,LA,~,~,~,~] = Allometry(PFTs,height,s,0);
%display(LA)

%% PHYSIOLOGY %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
for sh = 1:smax  %   Integration over smax size classes  
    if sg == 0
        if sum(sum(N(sh+1:smax+1,:),1)) == 0
            break
        end
    end
   
    s = 10;  % for integration over 10 sub-size classes up to sh
    Phinet = zeros(1,n);
    Phinet(:,:) = Phi_net(sh,:);    
    
    %   Vector of Flux of photon within the canopy < sh at every second [�mol.m^-2[photon].s^-1] (assume same below sh to approx Falster et al., 2011)
    Qsh  = Qt(:,1).*dEdz(sh,1)*ones(1,n);   % Total irradiance
    Qsw = Qts(:,1).*dEdz(sh,1)*ones(1,n);  % Short wave only (to estimate leaf temperature)
    
    %   Vector of Carbon concentration at every second in atmosphere (Catm), intercell (Cint) and in the carboxilation chamber (Ccarb)
    %   Highly simplified version for the relations (see Medvigy et al.,
    %   2009 for better model
    Cint   = CO2(:,1).*0.8*ones(1,n);    %  Poorter & Farquhar, 1994 (Austr. J Plant. Physiol) -
    Ccarb  = Cint.*0.7;                  %  ppm [micromol.mol] Ccarb (carboxylation) is lower than Cint
       
    %   Leaf temperature Tlc [C]: simple leaf energy balance equation (Moorcroft et al., 2001) 
    Phiconv = 38.4;                        %   Governs the rate of convective cooling [J/m2/s/K]
    lhv = (2.50084 - 0.00234.*Tc(:,1)).*10^6;  %   Latent heat of water vaporization [J/Kg of water]
    PhiKg = Phinet.*10E-6.*18.01528E-3;     %   Convert Phi_net [micromol H2O] into [Kg H2O]
    Tlc = (Qsw - lhv*PhiKg)./Phiconv + Tc(:,1)*ones(1,n);
    Tlc = real(Tlc);
    Tlc = 21.4; %21.4 on average Brench & Rincher, 2008 (Nature) - Subtropical to boreal convergence of tree-leaf temperatures
    %   Michaelis-Menten coefficient for C02 (K1) and 02 (K2) [mol/mol]
    K1     = 1.5E-4.*exp(6000.*(1/288.2 - 1./(Tlc + 273.2)));	   % Moorcroft et al., 2001
    K2     = 0.836.*exp(-1400.*(1/288.2 - 1./(Tlc + 273.2)));     % Moorcroft et al., 2001
      
    %   Tau: Co2 compensation point [mol/mol]
    Tau    = 2.12E-5.*exp(5000.*(1./288.2 - 1./(Tlc + 273.2)));    
    
    %Nitrogen density in the leaves [g/m2] (Wright et al., 2004: see suplementary info for SMA slopes section 3.3)
    Nad = (LMA./(10.^0.52)).^0.379;    
    
    %   Maximum capacity of Rubisco Jc [micromol/m2/s]: Nikolov et al., 1995; Jin-Sheng He et al., 2006; Kattge et al., 2009
    fac = 0.5; % Moorcroft et al., 2001 suggest field values Vmax25 ~ 15 micromol/m2/s, which is ~ 2-4 times lower than what this model predicts
    Vcmax25 = ones(t,1)*(Nad.*25.9 + 6.35).*fac; % for non-oxisol replace by .*25.9 + 6.35. for oxisol: .*10.71 + 1.99
    Vcmax   = (Vcmax25.*exp(3000.*(1./288.2 - 1./(Tlc + 273.2)))./((1+exp(0.4.*(5 - Tlc))).*(1 + exp(0.4.*(Tlc - 45)))));
    %Vcmax  = k25v*(Hdv*exp(Hav*(Tl-Toptv)/(Tl*Rgas*Toptv))/(Hdv-Hav*(1-exp(Hdv*(Tl-Toptv)/(Tl*Rgas*Toptv)))));   % Meydlin et al., 2002
    Jc = Vcmax.*(Ccarb.*10^-6 - Tau)./(Ccarb.*10^-6 + (K1.*(1 + K2)));        % Moorcroft et al., 2001    
    
    %   Photosynthesis demand when stomata are closed (respiration) [micromol/m2/s]
    Ac = - 0.02.*Vcmax;
   
    %   Assume saturated vapour pressure (SVP) inside the leaf [hPa]
    SVPl = exp(1.8096 + (17.269425 .* Tlc)./(237.3 + Tlc));    
    %   Water vapour deficit in the leaf - air: [mol/mol], which is just the vapour pressure in kPa / 100kPa or hPA / 1000hPA
    Ds  = (SVPl - VPa*ones(1,n)).*10^-1; 
    
    %   Light limited rate of photosynthesis when the RuBP activity is
    %   limited (simplification: assume same amount of light within sh [micromol/m2/s]
    
    phij = 0.04; % Changing this value will change the speed at which the forest grow but not the asymptotic biomass under closed canopy
                 % (values found in litterature %(phij = 0.08: Moorcroft et al., 2001; phij = 0.04: Falster et al., 2011)
    %Je     = phij.*Qsh.*(Ccarb.*10^-6 - Tau)./(Ccarb.*10^-6 - 2.*Tau);  
    %   Nikolov et al., 1995;
    Jm25 = ones(t,1)*(30.*Nad + 30);  % relation between LMA and Jmax25 (average value
    Jmax = Jm25.*exp((3.3621E-3 .* (Tlc + 273.2) - 1) .* Ea./(Rgas*(Tlc+ 273.2)))./(1 + exp((Se.*(Tlc+ 273.2) - He)./(Rgas*(Tlc+ 273.2))));
    Je = ((Jmax + phij.*Qsh) - sqrt((Jmax + phij.*Qsh).^2 - 4.*thetaj.*phij.*Qsh.*Jmax))./(2.*thetaj);
    %   Photosynthetic assimilation when open stomata [micromol/m2/s]
    A0  = max(0,min(Jc,Je) + Ac);  %put max for calculation of stomatal conductance when open stomata
   
    %   stomatal conductance: [molH2O/m2/s]
    cso = 8.*A0./((Cint.*10^-6 - Tau).*(1 + Ds./0.01)) + 0.01;  % open stomata   (8 for C3, 4 for C4)
    csc = 0.01;   % closed-stomata    
    
    %   Probability density of leaf area at height z [m^-1]
    ddq      = zeros(s,n);    
    for z  = 1:s %   Integration over height z        
        if sg == 0
            %  2nd integration mid-point rule: xzz = [hsg+.5*((height-hsg)/s),hsg+.5*((height-hsg)/s)+((height-hsg)/s)*[1:s-1]]';
            dvec  = (((height(sh,:)' - hsg)./s)*[1:s-1]);
            dhsgt = (hsg + .5.*((height(sh,:)' - hsg)./s))*ones(1,s);
            dhsize = cat(2,zeros(n,1),dvec);
            xzz  = (dhsgt + dhsize)';
        elseif sg == 1
            %  2nd integration mid-point rule: xzz = [hsg+.5*((height-hsg)/s),hsg+.5*((height-hsg)/s)+((height-hsg)/s)*[1:s-1]]';
            dvec  = (((height(sh,:)')./s)*[1:s-1]);
            dhsgt = (.5.*((height(sh,:)')./s))*ones(1,s);
            dhsize = cat(2,zeros(n,1),dvec);
            xzz  = (dhsgt + dhsize)';
        end        
        ddq(z,:)  = (2.*n0.*(1 - (xzz(z,:).^n0).*height(sh,:).^(-n0))).*(xzz(z,:).^(n0 - 1)).*(height(sh,:).^-n0);
    end    
    dq = reshape(ddq',1,n,[]);
    q = repmat(dq,[t,1,1]);
    
    %   Evaporation rate at height z
    
    dPhi_O  = Ds.*cso;  % open stomata  micromol.mol^-1
    dPhi_c  = Ds.*csc;  % closed-stomata micromol.mol^-1
    
    
    
    
    %   Total water demand for the whole canopy [micromol[H2O]/sc]
    Phi_O = dPhi_O.*s.*((ones(t,1)*height(sh,:))./s); % sum over s height sub-size classes within sh and then *hbymin = (height(sh,:)./s for the mid-point rule    
    Phi_c = dPhi_c.*s.*((ones(t,1)*height(sh,:))./s); % sum over s height sub-size classes within sh and then *hbymin = (height(sh,:)./s for the mid-point rule
    
    Demand = Phi_O.*10^-6.*18.01528E-3.*(1./(ones(t,1)*LMA)).*(ones(t,1)*Bl(sh,:));
    Supply = Kw.*(rain + Water).*(ones(t,1)*Bfr(sh,:));  %asumption: add average rainfall per sec
    fow    = 1./(1 + Demand./Supply);
    
    
    %   Leaf-level evapotranspiration for the next time [micromol[H2O]/sc]
    dPhinet= fow.*Phi_O + (1 - fow).*Phi_c;    
   
    dPhinet(dPhinet<0) = 0;
    Phi_net(sh,:) = mean(dPhinet(:,:));
    Phinet = sum(dPhinet,1).*3600;
    
    
    %   Total water uptake during one month for each of the n PFT syndrome
    %   given .mol (10E-6), kg/mol[h20](18.01528E-3)
    Wupnet = Phinet.*10^-6*18.01528E-3.*(Bl(sh,:)).*(1./(LMA)).*1./(2 + 0.0012128.*(LMA).*(height(sh,:)));   % requires *3600 sec as it was previously 744 hours within a month;
    Wup(sh,:) = Wupnet; 
   
    %   Total assimilation integrated for the whole canopy for a second [micromol[C]/sc]
    dAnet =  ((repmat(fow,[1 1 s])).*(repmat(A0,[1 1 s])) + (1 - (repmat(fow,[1 1 s]))).*(repmat(Ac,[1 1 s]))).*q; %-Rroot;   % assuming 1/3 of assimilation is lost through growth respiration
    dA  = sum(dAnet,3).*(ones(t,1)*height(sh,:)./s);  % for integration *hbymin/s
    A  = sum(real(dA),1).*3600;   % sum across the month for each of the n PFT syndrome
       
    %   Respiration of roots
    Root  = sum(exp(3000.*(1./288.2 - 1./(real(Tc(:,1))*ones(1,n) + 273.2)))./((1 + exp(0.4.*(5-real(Tc(:,1))*ones(1,n)))).*(1 + exp(0.4.*(real(Tc(:,1))*ones(1,n) - 45)))).*(ones(t,1)*Bfr(sh,:)),1).*3600.*10^-6.*Cbio;    % Moorcroft et al., 2001
    %Rstem = (Bs(sh,:) + 2.*Bb(sh,:))./2;
    
    Resp = Root;% + Rstem;
    if sg == 0   %   Calculate the turnover per month (T)   Moorcroft et al., 2001
        sleaf = ((1./LMA)./16).^(-1./0.46);                  % leaf longevity
        Tleaf = Bl(sh,:).*1./sleaf;                          % leaf drop evergreen
        Troot = 1./sleaf.*Bfr(sh,:).*(1+exp(0.4.*(278.15 - real(Tc(t,1))))).^-1; % fine root
        Tbark = Bb(sh,:).*kb;                                % bark
        T = (Tleaf + Troot + Tbark)./12;
       elseif sg == 1
        T = zeros(1,n);
    end
    
    %   Net assimilation [Kg[C]/h]
    Akgdt    = Y.*Cbio.*(LA(sh,:).*A.*10.^-6);   % 10^-6 to transform from micromol to mol   , per hour (*3600)
       
    %   NET CARBON PRODUCTION over the month [Kg[C]/month]
    
    P(sh,:) = Akgdt - Resp - T;
    P=real(P);
    P(P<0)=0;
   
%% DEMOGRAHY %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
        
    if sg == 0    %  Deal with trees, not seedlings
        fr   = Cr1.*(1 + exp(Cr2.*(1 - height(sh,:)./hmat'))).^-1;  %   Fraction of production allocated to reproduction (hr)
        FWPGL = 1./(1 + (1 + beta1).*(1 + b).*STD.*nc.*theta.^(-1).*alpha1.*(LMA.^(-1 - beta1)).*(Bl(sh,:).^beta1)+STD.*nc.*alpha2.*beta2.*(LMA.^(-beta2)).*(Bl(sh,:).^(beta2-1)) + alpha3.*LMA.^(-1));   %   Fraction of whole plant that is leaf (FLAPL)  (see appendix S2 in Falster et al., 2011 (JoE) for details)
        Fm  = Cd0.*exp(-Cd1.*STD) + Cd2.*exp(-Cd3.*((P(sh,:).*12)./LA(sh,:))); %   Mortality force [year^-1]
        Fm = real(Fm);        
        Sk(sh,:)  = nthroot(exp(-Fm),12);         %   Monthly Survival rate
        Bxy = Bl(sh,:)+((1 - fr).*P(sh,:).*FWPGL);  %   Biomass after growing
        hy  = alpha1.*(Bxy.*LMA.^-1).^beta1;      %   Height after growing
        Gxy(sh,:) = real((hy-height(sh,:))./hbymin);    %   Growth rate from one height class hx to another hy
        Gxy(Gxy<0)= 0;        
        Fk(sh,:)  = (fr.*P(sh,:)./(Cacc.*Ssize));   %   Rate of seed production
       
    elseif sg == 1    % Deal with seedlings  
        Ssg  = ((((P(sh,:)./LA(sh,:)).^-2).*(Cs0.^2)+1).^-1);    % Seedling mortality   
       
    end
end










