%============================================================================================%
%   In the decision model, the manager is faced with important decisions that need to be
%   evaluated during two phases of forest regrowth5: 1) Regeneration - whether and
%   what species to plant 2) Stand maintenance - whether, and how to maintain the stand
%   by thinning (Fig. 2). This file describes the management decision model.
%   The user  assumes first that there is a limited number of species and limited range
%   of PFTs values that is practical to find, plant and thin in forests.
%   We reduced the possible set of traits to three well-known PFTs, namely seed mass (SM),
%   leaf mass per area (LMA) and timber density (TD), which are easy to measure (i.e., soft traits)
%   and different combinations of values for these three PFTs are frequently used to characterise
%   forest species. The model assumes that species belonging to a particular are similar
%   architecturally, physiologically and demographically. It also assumes that the management
%   practitioner can choose between eleven fixed management strategies that manipulate
%   the species with different Ω during the regeneration and maintenance phases.
%   During the regeneration phase (first year), decision practitioners must decide whether
%   they allow for natural regeneration, hereafter self-recovery, or they have to initiate
%   regeneration through technical reclamation planting. Planting fast growing trees to
%   initiate reforestation can provide increased canopy or a "framework" to aid in the
%   suppression of undesirable weed species and promote shade tolerant species in the understorey.
%   We call this the "framework functional trait" (FFT) method. The FFT supports the SEH
%   (Fig. 1, Fig.2). The second method involves more complex and expensive strategies that
%   plant a maximum diversity of species, each having a unique combination omega.
%   We call this method "maximum functional diversity" (MFD). The MFD supports the CH
%   (Fig. 1, Fig 2). During the maintenance phase, practitioners have to decide whether
%   they need to accelerate or maintain productivity of the stand over time, enhance desirable
%   target species with specific sets of PFTs, or eradicate non-target invasive species with
%   other sets of traits. We consider that practitioners have the choice between five actions:
%   no thinning (j == 1); thinning the dominant species every year (j == 2);
%   or implementing various strategies of selective thinning (ST) of specific PFTs
%   to accelerate succession toward denser timber for more resistant forests (j == 3),
%   toward greater seed mass (j == 4) in order to recruit taller trees, or toward more
%   productive and shade tolerant understory leaves with higher leaf mass per area LMA (j == 5).
%   We also assume the practitioner can implement different thinning regimes f, e.g.,
%   annually (f == 1), biennially (f == 2) or every five years (f == 5).
%============================================================================================%

clear
warning("off","Octave:divide-by-zero")
more off; 
pkg load statistics
tic
%format short G

%%  PHYSICAL CONDITIONS 
Tmax  = 2; %   Give the time horizon of the projections [years] 
Repmax = 100; %   Number of replicates if Forestry_Analysis == 4
Lat    = -27.467778;    %  Lattitude where the forest is
Long   = 153.027778;  % 	Longitude where the forest is
Clim = 1;    %   IPCC Climate change severity: low severity (wet-hot) == 1 , high severity (arid-hot) == 2
Land  = 2;  % Upland == 1 (water limited) , Lowland == 2 (no soil water limitation)
Farea = 10000;  %	Unit of area at which the forest ecosystem services are estimated [m2], with 10000 m2 = 1 ha
Nforestpatches = 1;   %   Baseline Number of forest patches for Farea (~ level of fragmentation)
Fregrowth = 0;   %	Initial state of the forest to restore: SF == n: n PFTs already present in the forest (n == 0: no forest)
Fsurroundings = 1;  %	Surrounding forests (important for seed colonization): SC == 0: no, SC == 1: yes.
Sand = 0.5;  %   Sand in the 1st 30cm of soil (sand + clay + silt = 1)
Clay = 0.3;   %   Clay in the 1st 30cm of soil (sand + clay + silt = 1)
Silt = 1 - (Sand + Clay);  %   Clay in the 1st 30cm of soil (sand + clay + silt = 1)
Organic = 0;   % do you consider the soil as organic (e.g., Peat)? Yes: 1, No:0
SoilDepth = 3;   %   Soil depth [m]: usually soils are 1-10m thick

%%  1. BIOLOGICAL SYSTEM
Timbermin = 400;   %  Minimum basic timber density of tree species in the forest  [kg/m3]
Timbermax = 1000;  % Maximum basic timber density of tree species in the forest [kg/m3]
LMAmin    = 0.05;  % 	Leaf economy [kg/m2] (Minimum average LMA for a species)
LMAmax    = 0.35;  % 	Leaf economy [kg/m2] (Maximum average LMA for a species)
Seedmin   = 10^-7;   % 	Seed economy: Minimum seed size at maturity for a species, 10⁻7 kg in the literature
Seedmax   = 10^-4;  % 	Seed economy: Maximum seed size at maturity for a species, 10⁻7 kg in the literature
nLHT = 3;   % Max number of Life History classes between the min and the max values (includes the min and max)

%%  FORESTRY SYSTEM
    %   Analysis = 1, search for optimal forestry strategies (Pichancourt et al., 2014)
    %   Analysis = 2, explore consequences of existing behaviours over 3^(nTimbermax*nLMAmax*nSeedmax) possibilities of forestry behaviours in the same forest
    %   Analysis = 3, sensitivity analysis by comparing the effect of forestry behaviours in different forests characterised by different levels of species diversity.
    %   Analysis = 4, sensitivity analysis of the maximum forestry practice with random variables
Forestry_Analysis = 3;
Silviculture = 1;  %   Are you planning to invest in post harvesting forestry practices (weeding + replanting)? If yes then 1, no then 0.
Plantmax = 2;  %   Number of planting strategy you want to test: (1) doing nothing, (2) Framework Planting Method, (3) Maximum Diversity Method
Nplant = 1/2; %   Planting density per m2
ThinDivmax = 2; %   Thinning of dominant PFTS if canopy openness < 1%; 3 = Yes all individuals of dominant PFTS
ThinFreqmax = 2; %   Thinning frequency (1: every years, 2: every two years ...)

%%  ECONOMIC SYSTEM
Pselltimber = 1; %   Probability selling timber
Eplanting = [.5 .25 .25]; %   Baseline Proportion of trees planted for respectively firewood, timber, ntfp (fruits ...)

%%  SOCIAL SYSTEM
Efficient_manager = 1; %   Baseline Management efficiency: planting, weeding, pruning, etc ... (best = families; communities and state less good)
Efficient_monitor = 1;  %   Baseline Monitoring efficiency: poaching ... (best = communities, less good = individual families and state less good)
NumberHH = 1; %   Number of household that have access to this patch of forest
SizeHH = 5;  %   Average Size of household (number of members per households)
Access = 1;  %   Average access rate to the forest per household (no access: 0, open access:1), %   NB: need to distinguish Access rate for timber, firewood, etc ...

%% OUTPUTS TO BE DISPLAYED ON FIGURE
%           Carbon == 1: Total organic carbon in the forest (TOC)
%           Carbon == 2: Above-ground organic carbon (AGOC)
%           Carbon == 3: Litter organic carbon (LOC)
%           Carbon == 4: Soil organic carbon (SOC)
%           Carbon == 5: Total organic carbon excluding litter (TOC - LOC)
Tcarbon = 1;

%%  STORE INPUT VARIABLES
SoilElements = [Sand Clay Silt Organic];
Physics = [Tmax Lat Long Clim Land Farea Nforestpatches Fregrowth Fsurroundings SoilElements SoilDepth]';
Biology = [Timbermin Timbermax LMAmin LMAmax Seedmin Seedmax nLHT]';
Economics = [Pselltimber Eplanting]';
Social = [NumberHH SizeHH Access]';
Forestry = [Plantmax Nplant ThinDivmax ThinFreqmax Forestry_Analysis Efficient_manager Efficient_monitor Silviculture]';
Outputs = [Tcarbon]';

%%  MODEL THE BIOCULTURAL SYSTEM
BCD = Analyses(Physics, Biology, Forestry, Economics, Social, Outputs, Repmax);



