function [Nsnags,BNsnags,BNdebris] = Snag(Nsnags,dNsnags,BNdebris,dB,T,PFTs,height)

%%  Definitions
Parameters
dBl = dB(:,:,2);
dBbr = dB(:,:,3);
dBtr = dB(:,:,4);
dBb = dB(:,:,6);
dBfr = dB(:,:,8);
dBcr = dB(:,:,9);
dBt = dBl + dBbr + dBtr + dBb + dBcr + dBfr;
TD = PFTs(:,1);

%%  SNAG FALL (downed woody debris). Traits that increase the conversion of standing snags to downed wood" (Cornwell et al., 2009)
%   Assumes standing death is the only reason for tree mortality, as
%   observed by Vanderwel et al. (2006) and others cited in the paper (wind not important, no fire)
BAh = 0; % basal area harvested
alpha = 5.691;
gamma = [0 .177 .542 .702 .528];
zeta = -3.777;
nu = 0.531;
kappa = 0.157;
sigma = 0.234;

%%  Monthly Decay transition matrix, based on 5 years transition decay matrix (Vanderwel et al., 2006)

%   Transition matrix between Decay Classes 1-5 (C1-C5, Table1: Vanderwel et al.,2006))
%   - Decay Class 1: Tree is recently dead; top is intact; most fine branching is still present; bark is intact
%   - Decay Class 2: Top is intact; most of the fine branches have dropped; more than 50% of the coarse branches are left; bark may begin to lossen
%   - Decay Class 3: Top is intact; fewer than 50% of the coarse branches are left; bark may or may not have sloughed off
%   - Decay class 4: Top is broken; no coarse branches remain; bark may or may not have sloughed off; height is at least 6m
%   - Decay class 5: Top repeatedely broken; no coarse branches remain; bark may or may not have sloughed off; height is less than 6m
%     C1     C2      C3      C4      C5
Dc = [.045   0       0       0       0
      .186   .165    0       0       0
      .329   .379    .351    0       0
      .166   .204    .346    .527    0
      .274   .252    .303    .473    1].^(1/(12*5));

dbh = (height.^(1./alpha9))./(beta9.^(1./alpha9));
dbh(dbh < 4.106/100) = 4.2/100;

%%  Integrate the new snags into the size-by-decayclass snag vector
Nsnags(1:size(dNsnags,1),:) = dNsnags(:,:);

%%  Vec-permutation matrix (Hunter & Caswell, 2005)
r = size(Dc,2);
s = size(dNsnags,1);
P = zeros(r*s,r*s);
for i = 1:s
    for j = 1:r
        Esr = zeros(s,r);
        Esr(i,j) = 1;
        dP = kron(Esr,Esr');
        P = P + dP;
    end
end

%   define population vector of debris
Ndebris = zeros(s*r,size(Nsnags,2));

%   Start loop for snap dynamics per species
for i = 1:size(PFTs,1)
    %   Transition block-matrix: transition matrix by size-classes 
    Tr = kron(eye(size(dNsnags,1),size(dNsnags,1)),Dc);
    %   Survival block-matrix: size-classes by transition classes 
    beta = -0.0032.*diag(ones(size(dNsnags,1),1).*TD(i,1)) + 1.9635; % estimated from the list of species provided in Vanderwel et al. (2006)
    Sx1 = alpha + beta + zeta.*log(diag(dbh(:,i),0)) + nu.*log(diag(dbh(:,i),0)).^2 + kappa*BAh + gamma(1,1) + (sigma.*randn(1,1));
    Sx2 = alpha + beta + zeta.*log(diag(dbh(:,i),0)) + nu.*log(diag(dbh(:,i),0)).^2 + kappa*BAh + gamma(1,2) + (sigma.*randn(1,1));
    Sx3 = alpha + beta + zeta.*log(diag(dbh(:,i),0)) + nu.*log(diag(dbh(:,i),0)).^2 + kappa*BAh + gamma(1,3) + (sigma.*randn(1,1));
    Sx4 = alpha + beta + zeta.*log(diag(dbh(:,i),0)) + nu.*log(diag(dbh(:,i),0)).^2 + kappa*BAh + gamma(1,4) + (sigma.*randn(1,1));
    Sx5 = alpha + beta + zeta.*log(diag(dbh(:,i),0)) + nu.*log(diag(dbh(:,i),0)).^2 + kappa*BAh + gamma(1,5) + (sigma.*randn(1,1));
    S1 = (exp(Sx1)./(1 + exp(Sx1))).^(1/(12*5));
    S2 = (exp(Sx2)./(1 + exp(Sx2))).^(1/(12*5));
    S3 = (exp(Sx3)./(1 + exp(Sx3))).^(1/(12*5));
    S4 = (exp(Sx4)./(1 + exp(Sx4))).^(1/(12*5));
    S5 = (exp(Sx5)./(1 + exp(Sx5))).^(1/(12*5));
    S = blkdiag(S1,S2,S3,S4,S5);
    S(isnan(S)) = 0;
    %   Mortality block matrix
    M = blkdiag(1 - S1,1 - S2,1 - S3,1 - S4,1 - S5);    
    M(isnan(M)) = 0;
    %   Projection matrix: transition to a decay state then survival (or mortality) 
    %   Organized useing vec-permutation (Hunter & Caswell, 2005)
    A1 = S*P'*Tr*P; %
    A2 = M*P'*Tr*P;
    %%  Estimate new debris produced from Snags
    
    Nsnags(:,i) = A1*Nsnags(:,i);   
    Ndebris(:,i) = A2*Nsnags(:,i);
end

%%  Update snag biomass 
dBdebris = cat(1,dBl + dBfr + sum(T),0.5.*(dBbr + dBcr),0.5.*(dBbr + dBcr),0.5.*(dBtr),0.5.*(dBtr)); 
dBsnags = cat(1,dBt - (dBl + dBfr),dBt - (dBl + dBfr ) - 0.5.*(dBbr + dBcr),dBt - (dBl + dBfr) - (dBbr + dBcr),dBt - (dBl + dBfr) - (dBbr + dBcr) - 0.5.*(dBtr),zeros(size(dBt,1),size(dBt,2)));             
BNdebris(:,:,1) = BNdebris(:,:,1) + Ndebris(1:size(dBl,1),:).*dBdebris(1:size(dBl,1),:);
BNdebris(:,:,2) = BNdebris(:,:,2) + Ndebris(1:size(dBbr,1),:).*dBdebris(1:size(dBbr,1),:);
BNdebris(:,:,3) = BNdebris(:,:,3) + Ndebris(1:size(dBtr,1),:).*dBdebris(1:size(dBtr,1),:);
BNdebris(:,:,4) = BNdebris(:,:,4) + Ndebris(1:size(dBb,1),:).*dBdebris(1:size(dBb,1),:);
BNdebris(:,:,5) = BNdebris(:,:,5) + Ndebris(1:size(dBcr,1),:).*dBdebris(1:size(dBcr,1),:);
BNdebris(:,:,6) = BNdebris(:,:,6) + Ndebris(1:size(dBfr,1),:).*dBdebris(1:size(dBfr,1),:);
%display(sum(sum(sum(BNdebris))))
BNsnags = Nsnags.*dBsnags;

end

%%  MANUAL & REFERENCES  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%   - REF1: Garber, S. M., Brown, J. P., Wilson, D. S., Maguire, D. A., & Heath, L. S. (2005). Snag longevity under alternative silvicultural regimes in mixed-species forests of central Maine. Canadian Journal of Forest Research, 35(4), 787-796.
%   - REF2: Vanderwel, M. C., Caspersen, J. P., & Woods, M. E. (2006). Snag dynamics in partially harvested and unmanaged northern hardwood forests. Canadian Journal of Forest Research, 36(11), 2769-2779.
%   - REF2: Hunter, C. M., & Caswell, H. (2005). The use of the vec-permutation matrix in spatial matrix population models. Ecological modelling, 188(1), 15-21.