%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%   ISLSCP Soil hydrology parameters  (Sellers et al., 1995, Moorcroft et al., 2001)
%   
%   Type of soil: Stype == 1 (coarse), 
%                       == 2 (medium/coarse)
%			== 3 (medium)
%			== 4 (fine/medium)
%			== 5 (fine) 
%			== 6 (organic) 
%	%
%                                       100/\
%                                         /  \
%                                      90/    \10
%                                       /      \
%                                    80/        \20
%                                     /          \
%                     / \          70/            \30
%                      |            /              \
%                      |         60/                \40
%                      |          /       FINE       \
%                Percent clay  50/                    \50  Percent silt
%                               /                      \         |
%                            40/                        \60      |
%                             /--------------------------\       |
%                          30/                            \70   \ /
%                           /                              \
%                        20/                                \80
%                         /--------          MEDIUM          \
%                      10/         \                          \10
%                       /    COARSE \                          \
%                       ----------------------------------------\
%                     100  90  80  70  60  50  40  30  20  10   
%                                   <--------------
%                                     Percent sand
%	
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [hb,thetamax,thetamin,Ksat,tauS,Water,STypeUSDA] = Soil(SoilElements)

Sand = SoilElements(1,1);
Clay = SoilElements(2,1);
Organic = SoilElements(4,1);
%%  Broad classification of soil based on granulometry
if Sand >= .65 && Clay <= .15 
    Stype = 1;
        
elseif (Sand < .65 && Clay <= .15) ||  (.15 < Clay && Clay <= .35)
    Stype = 3;

elseif Clay > .35
    Stype = 5;
    
elseif Organic == 1
    Stype = 6;    
end    
    
if Stype == 1        % Coarse soil
	dg       = 20;          %  Bulk diameter (geometric mean particul size [cm]
	hb       = 5*dg^-0.5;   %  Bubling pressure [cm]
    thetamin = 0.025;       %  residual soil moisture [cm3/cm3]
    thetamax = 0.0363;      %  Maximum soil moisture [cm3/cm3]
	Ksat     = 14.1E-6;     %  Saturated hydraulic conductivity [m/s]
	tauS     = 4.26;        %  Empirical parameter governing the rate at which conductivty devreases as saturation level decreases[cm3/cm3]

elseif Stype == 2    % medium/coarse soil
	dg       = 5;           
    hb       = 5*dg^-0.5; 
    thetamin = 0.01;        
    thetamax = 0.1413;
	Ksat     = 5.23E-6;
	tauS     = 4.74; 
	
elseif Stype == 3   % medium soil
	dg       = 0.6;           
    hb       = 5*dg^-0.5; 
    thetamin = 0.01;        
    thetamax = 0.3548;
	Ksat     = 3.38E-6;
	tauS     = 5.25;
	
elseif Stype == 4   %  fine/medium soil
	dg       = 0.1;           
    hb       = 5*dg^-0.5; 
    thetamin = 0.025;        
    thetamax = 0.1349;
	Ksat     = 4.45E-6;
	tauS     = 6.67;
	
elseif Stype == 5   %  fine soil
	dg       = 2*10^-2;           
    hb       = 5*dg^-0.5; 
    thetamin = 0.01;        
    thetamax = 0.263;
	Ksat     = 2.45E-6;
	tauS     = 8.17;
	
elseif Stype == 6   %  organic soil
	dg       = 10^-3;           
    hb       = 5*dg^-0.5;     
    thetamin = 0.01;        
    thetamax = 0.354;
	Ksat     = 3.38E-6;
	tauS     = 5.25;
end

%   Initial water availability in the soil [mm] = [kg/m2]
    Water = 1000;

%%  USDA soil classification
% Soil Texture Index Number
    % 0) ERROR
    % 1) Sand
    % 2) Loamy sand
    % 3) sandy loam
    % 4)sandy clay loam
    % 5) loam
    % 6) silt loam
    % 7) silt
    % 8) sandy clay
    % 9) clay loam
    % 10) silty clay loam
    % 11) clay
    % 12) silty clay
% output.soil_A : Silt ??? ??? SIlt ? ???, SIlt? ???, Sand? Clay? ???
%                    SIlt?? ?? ??? ??, ? ??? A(:,4)? ????, A(:,5)?
%                    ??? Silt? ????.
% ==================================================================================================
% Copyright: wh1988ha@gmail.com, 2013
% author: http://blog.daum.net/wh1988ha
% version : v1.01
% ==================================================================================================
%
%                                       100/\
%                                         /  \
%                                      90/    \10
%                                       /      \
%                                    80/        \20
%                                     /          \
%                     / \          70/            \30
%                      |            /              \
%                      |         60/       C        \40
%                      |          /                 /\
%                Percent clay  50/\                /  \50  Percent silt
%                               /  \              / SiC\         |
%                            40/ SC \____________/______\60      |
%                             /______\     CL    \ SiCL  \       |
%                          30/ SCL    \___________\_______\70   \ /
%                           /_________/          /         \
%                        20/_         \    L    /   SiL     \80
%                         /  \_   SL   \       /             \
%                      10/\_   \_       \_____/         ______\90
%                       / S \ LS \_          /         /  Si   \
%                      /_____\_____\________/_________/_________\
%                     100  90  80  70  60  50  40  30  20  10   
%                                   <--------------
%                                     Percent sand
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

x = (100 - Sand*100 - Clay*100/2) ;
y = Clay*100*sqrt(3)/2 ;

% --------------------------------------------------
% 1) sand
    if (0<=x(1,1) && x(1,1)<5 && y(1,1)>=0 && y(1,1)<= sqrt(3)*x(1,1)) ||...
            (5<=x(1,1) && x(1,1)<15 && y(1,1)>=0 && y(1,1)< -1*sqrt(3)/2*x(1,1)+15*sqrt(3)/2)
        STypeUSDA = 'sand' ;        
       
% 2) loamy sand
    elseif (5<=x(1,1) && x(1,1)<7.5 && y(1,1)>=-1*sqrt(3)/2*x(1,1)+15*sqrt(3)/2 && y(1,1)<= sqrt(3)*x(1,1)) ||...
            (7.5<=x(1,1) && x(1,1)<15 && y(1,1)>=-1*sqrt(3)/2*x(1,1)+15*sqrt(3)/2 && y(1,1)<-7.5*sqrt(3)/22.5*(x(1,1)-30) ) ||...
            (15<=x(1,1) && x(1,1)<30 && y(1,1)>=0 && y(1,1)<-7.5*sqrt(3)/22.5*(x(1,1)-30) )
        STypeUSDA = 'loamy sand' ;
        
% 3) sandy loam
    elseif ( 7.5 <=x(1,1)  &&  x(1,1)< 10  && y(1,1)>= -1/sqrt(3)*(x(1,1)-30)  && y(1,1)<= sqrt(3)*x(1,1) ) ||...
            (10 <=x(1,1)  &&  x(1,1)< 30  && y(1,1)>= -1/sqrt(3)*(x(1,1)-30)  && y(1,1)< 10*sqrt(3) )||...
            (30 <=x(1,1)  &&  x(1,1)< 37.5  && y(1,1)>= 0  && y(1,1)< 10*sqrt(3) )||...
            (37.5 <=x(1,1)  &&  x(1,1)< 43.75  && y(1,1)>= 0  && y(1,1)< -1*sqrt(3)*(x(1,1)-47.5) )||...
            (43.75 <=x(1,1)  &&  x(1,1)< 50  && y(1,1)>= 0  && y(1,1)< 3.75*sqrt(3) )||...
            (50 <=x(1,1)  &&  x(1,1)< 53.75  && y(1,1)>= sqrt(3)*(x(1,1)-50) && y(1,1)< 3.75*sqrt(3))
        STypeUSDA = 'sandy loam' ;
        
% 4)sandy clay loam
    elseif (10 <=x(1,1)  &&  x(1,1)< 17.5  && y(1,1)>= 10*sqrt(3)  && y(1,1)<= sqrt(3)*x(1,1) ) ||...
            (17.5<=x(1,1)  &&  x(1,1)< 37.5  && y(1,1)>= 10*sqrt(3)  && y(1,1)< 17.5*sqrt(3) ) ||...
            (37.5 <=x(1,1)  &&  x(1,1)< 41.25  && y(1,1)>= sqrt(3)*(x(1,1)-27.5)  && y(1,1)< -1*sqrt(3)*(x(1,1)-55))
        STypeUSDA = 'sandy clay loam' ;
        
% 5) loam
    elseif (37.5 <=x(1,1)  &&  x(1,1)< 41.25 && y(1,1)>= -1*sqrt(3)*(x(1,1)-47.5) && y(1,1)< sqrt(3)*(x(1,1)-27.5) ) ||...
            (41.25 <=x(1,1)  &&  x(1,1)< 43.75 && y(1,1)>= -1*sqrt(3)*(x(1,1)-47.5)  && y(1,1)< 13.75*sqrt(3) ) ||...
            (43.75 <=x(1,1)  &&  x(1,1)< 53.75 && y(1,1)>= 3.75*sqrt(3)  && y(1,1)< 13.75*sqrt(3) ) ||...
            (53.75 <=x(1,1)  &&  x(1,1)< 63.75  && y(1,1)>= sqrt(3)*(x(1,1)-50)  && y(1,1)< 13.75*sqrt(3))
        STypeUSDA = 'loam' ;
        
% 6) silt loam
    elseif (50 <=x(1,1)  &&  x(1,1)< 63.75 && y(1,1)>= 0  && y(1,1)< sqrt(3)*(x(1,1)-50) ) ||...
            (63.75 <=x(1,1)  &&  x(1,1)< 80 && y(1,1)>= 0  && y(1,1)< 13.75*sqrt(3) ) ||...
            (80 <=x(1,1)  &&  x(1,1)< 86.25 && y(1,1)>= sqrt(3)*(x(1,1)-80)  && y(1,1)< 13.75*sqrt(3) ) ||...
            (86.25 <=x(1,1)  &&  x(1,1)<=93.75  && y(1,1)>= 6.25*sqrt(3)  && y(1,1)<= -1*sqrt(3)*(x(1,1)-100))
        STypeUSDA = 'silt loam' ;
        
% 7) silt
    elseif (80 <=x(1,1)  &&  x(1,1)< 86.25 && y(1,1)>= 0 && y(1,1)< sqrt(3)*(x(1,1)-80) ) ||...
            (86.25 <=x(1,1)  &&  x(1,1)<= 93.75 && y(1,1)>= 0 && y(1,1)< 6.25*sqrt(3) ) ||...
            (93.75 <=x(1,1)  &&  x(1,1)<= 100  && y(1,1)>= 0 && y(1,1)<= -1*sqrt(3)*(x(1,1)-100) )
        STypeUSDA = 'silt' ;
        
% 8) sandy clay
    elseif (17.5 <=x(1,1)  &&  x(1,1)< 27.5  && y(1,1)>= 17.5*sqrt(3)  && y(1,1)<= sqrt(3)*x(1,1) ) ||...
            (27.5<=x(1,1)  &&  x(1,1)< 37.5  && y(1,1)>= 17.5*sqrt(3)  && y(1,1)< -1*sqrt(3)*(x(1,1)-55))
        STypeUSDA = 'sandy clay' ;
        
% 9) clay loam
    elseif (35 <=x(1,1)  &&  x(1,1)< 41.25 && y(1,1)>= -1*sqrt(3)*(x(1,1)-55)  && y(1,1)< 20*sqrt(3) ) ||...
            (41.25 <=x(1,1)  &&  x(1,1)< 60 && y(1,1)>= 13.75*sqrt(3)  && y(1,1)< 20*sqrt(3) ) ||...
            (60 <=x(1,1)  &&  x(1,1)< 66.25  && y(1,1)>= 13.75*sqrt(3)  && y(1,1)< -1*sqrt(3)*(x(1,1)-80))
        STypeUSDA = 'clay loam' ;
        
% 10) silty clay loam
    elseif (60 <=x(1,1)  &&  x(1,1)< 66.25  && y(1,1)>= -1*sqrt(3)*(x(1,1)-80)  && y(1,1)< 20*sqrt(3) ) ||...
            (66.25 <=x(1,1)  &&  x(1,1)< 80 && y(1,1)>= 13.75*sqrt(3)  && y(1,1)< 20*sqrt(3) ) ||...
            (80 <=x(1,1)  &&  x(1,1)< 86.25  && y(1,1)>= 13.75*sqrt(3)  && y(1,1)<= -1*sqrt(3)*(x(1,1)-100))
        STypeUSDA = 'silty clay loam' ;
        
% 11) clay(1,1)
    elseif (27.5 <=x(1,1)  &&  x(1,1)< 35  && y(1,1)>= -1*sqrt(3)*(x(1,1)-55) && y(1,1)<= sqrt(3)*x(1,1) ) ||...
            (35 <=x(1,1)  &&  x(1,1)< 50  && y(1,1)>= 20*sqrt(3)  && y(1,1)<= sqrt(3)*x(1,1) ) ||...
            (50 <=x(1,1)  &&  x(1,1)< 60 && y(1,1)>= 20*sqrt(3)  && y(1,1)<= -1*sqrt(3)*(x(1,1)-100) ) ||...
            (60 <=x(1,1)  &&  x(1,1)< 70  && y(1,1)>= sqrt(3)*(x(1,1)-40)  && y(1,1)<= -1*sqrt(3)*(x(1,1)-100))
        STypeUSDA = 'clay' ;
        
% 12) silty clay
    elseif (60 <=x(1,1)  &&  x(1,1)< 70  && y(1,1)>= 20*sqrt(3)  && y(1,1)< sqrt(3)*(x(1,1)-40) ) ||...
            (70 <=x(1,1)  &&  x(1,1)< 80  && y(1,1)>= 20*sqrt(3)  && y(1,1)<= -1*sqrt(3)*(x(1,1)-100))
        STypeUSDA = 'silty clay' ;
            
    end
    
