function  [rs,t,d,z,a,r] = suncycle(lat,lon,date,n)

% SUNCYCLE  returns the Time of SunRise, SunSet, Solar Altitude and Radiation%
% [SunRiseSet,Day,Dec,Alt,Azm,Rad] = SUNCYCLE( Lat , Lon , Date , N );%
%----------------------------------------------------------------------------
% Inputs:%
%   Lat , Lon = geographical Position, scalars%
%   Date      = [ YYYY MM DD ] or DateNum, multiple Rows allowed
%                default: actual Date%
%   N         = Resolution for Estimation, optional,
%                default: 2880 (30 sec Intervall)%
%----------------------------------------------------------------------------
% OutPut:%
%  SunRiseSet = [ SunRiseTime  SunSetTime ], decimal hour, refers to GMT
%                 special Values: [  0  24 ] Polar Day
%                                 [ 24   0 ] Polar Night%
%  Day        = Decimal Day since [ YYYY 01 01 ], N Columns%
%  Dec        = Solar Declination,        N Columns
%  Alt        = Solar Altitude,           N Columns
%  Azm        = Solar Azimuth,            N Columns
%  Rad        = Solar Radiation (no-sky), N Columns, [W/m?]
%               perpendicular to Earth Surface, i.e. normalized with sin(Alt) 
%----------------------------------------------------------------------------
% Code adapted from: AIR_SEA TOOLBOX (version 2.0: 8/9/99)
%                    Rich Pawlowicz %
% It is put together from expressions taken from Appendix E in the
% 1978 edition of Almanac for Computers, Nautical Almanac Office, U.S.
% Naval Observatory. They are reduced accuracy expressions valid for the
% years 1800-2100. Solar declination computed from these expressions is
% accurate to at least 1'.
%
%********************************************************

rs = [];
z  = [];
r  = [];
t  = [];
d  = [];

Nin = nargin;

if Nin < 3
   date = clock;
   date = date(1:3);
elseif isempty(date)
   return
elseif size(date,2) == 1
   date = datevec(date);
elseif ~( size(date,2) >= 3 )
   date = cat(2,date,ones(size(date,1),3));
end

if Nin < 4
   int = 30;  % Intervall [sec]
    n  = ceil( 24*3600 / int );
end

%********************************************************

lon = lon - 360 * floor( ( lon + 180 ) / 360 );  % [ -180 .. 180 )
t = datenum(date(:,1),date(:,2),date(:,3)) - datenum(date(:,1),01,01);
m = size(t,1);
dt = 1/n;
t = t(:,ones(1,n)) + dt * ones(m,1) * ( 0 : n-1 ) - lon/360;
[d,z,a,r] = soradna(lat,lon,t,date(:,1));

%********************************************************
% SunRise/SunSet

rs = NaN * ones(m,2);
zz = double( abs(r) <= 1e-10 );
sz = sum(zz,2);
ok = ( ( 0 < sz ) & ( sz < n ) );
if any(ok)

    nn = sum(ok);
    ok = find(ok);
    rs(ok,1) =     sum(cumprod(zz(ok,:),2),2);
    rs(ok,2) = n - sum(cumprod(zz(ok,n:-1:1),2),2) + 1;
    rs(ok,:) = min(max(rs(ok,:),1),n);
    rs(ok,:) = t( ok(:,[1 1]) + ( rs(ok,:) - 1 ) * m );
    rs(ok,:) = 24 * ( rs(ok,:) - floor(rs(ok,:)) );

    rs(ok,:) = rs(ok,:) + 24 * dt/2 * ( ones(nn,1) * [ 1  -1 ] );

end

ok = ( sz == n );   % Night
if any(ok)
   nn = sum(ok);
   ok = find(ok);
   rs(ok,:) = ( ones(nn,1) * [ 24  0 ] );
end

ok = ( sz == 0 );   % Day
if any(ok)
   nn = sum(ok);
   ok = find(ok);
   rs(ok,:) = ( ones(nn,1) * [ 0  24 ] );
end



        
        
	